*appendix_altfiringfig

version 12.1

cap project, doinfo
if _rc==0 {  
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
	clear
	local doasproject=0
	local pdir "~/projects/performancepay/project"
	local dofile "appendix_altfiringfig"
	local sig "Not run as part of project!"

}
local thisdir "`pdir'/appendix"
local scratch "`pdir'/scratch"
local sig_t=0.15

#delimit;
set more off;
set scheme lean1;

if `doasproject'==1 {;
  project, uses("`pdir'/scratch/appendix_altfiringruns_fire0.dta.gz");
  project, uses("`pdir'/scratch/appendix_altfiringruns_fireavgva0.dta.gz");
  project, uses("`pdir'/scratch/appendix_altfiringruns_fireopt0.dta.gz");
  project, uses("`pdir'/scratch/appendix_altfiringruns_tenure0.dta.gz");
};

if c(os)=="MacOSX" local zcatcmd "gzcat";
else local zcatcmd "zcat";

*A program to smooth series;
cap program drop smooth3;
program define smooth3;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(3*`origvar' 
                           + 2*(`origvar'[_n-1] + `origvar'[_n+1])
                           + 1*(`origvar'[_n-2] + `origvar'[_n+2]))/9
            if _n>2 | _n<_N-1;
 `bytxt' replace `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n==2 | _n==_N-1;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            

foreach f in fire fireavgva  tenure fireopt {;

 cap confirm file "`scratch'/appendix_altfiringruns_`f'0.dta";
 if _rc==0 {;
   cap confirm file "`scratch'/appendix_altfiringruns_`f'0.dta.gz";
 	 if _rc==0 {;
 	 	 !\rm `scratch'/appendix_altfiringruns_`f'0.dta;
 	 	 !`zcatcmd' `scratch'/appendix_altfiringruns_`f'0.dta.gz > `scratch'/appendix_altfiringruns_`f'0.dta;
 	 };
 };
 else !`zcatcmd' `scratch'/appendix_altfiringruns_`f'0.dta.gz > `scratch'/appendix_altfiringruns_`f'0.dta;
 *Work out Pr(fired), length of career;
  use `scratch'/appendix_altfiringruns_`f'0.dta, clear;
  sort id year;
  by id: gen survwgt_base=Surv-Surv[_n+1];
  by id: replace survwgt_base=Surv if _n==_N;
  gen survwgt_alt=survwgt_base*(firedyet_==0);
  by id: gen everfired=firedyet_[_N]==1 | fired_[_N]==1;
  gen fireyear=year if fired_==1;
  by id: egen firedate=min(fireyear);
  replace firedate=. if everfired~=1;
  gen mupt=round(normal(mu/`sig_t'), 0.01);
  gen yearwgt_base=year*survwgt_base;
  gen yearwgt_alt=year*survwgt_alt;
  collapse (sum) yearwgt_base yearwgt_alt survwgt_base survwgt_alt 
           (mean) mu firedate everfired 
           , by(mupt);
  gen avglength_base=yearwgt_base/survwgt_base;
  gen avglength_alt=yearwgt_alt/survwgt_alt;
  smooth3, newvar(avglength_`f') origvar(avglength_alt);
  smooth3, newvar(everfired_`f') origvar(everfired);
  smooth3, newvar(firedate_`f') origvar(firedate);
  gen davglength_`f'=100*(avglength_`f'/avglength_base)-100;
  keep mu mupt avglength_base avglength_`f' everfired_`f' davglength_`f' firedate_`f';
  rename avglength_base avglength_base_`f';
  tempfile `f';
  save ``f'';
 };


use `fire';
merge 1:1 mupt using `fireavgva', assert(3);
drop _merge;

merge 1:1 mupt using `fireopt', assert(3);
drop _merge;

merge 1:1 mupt using `tenure', assert(3);
drop _merge;

gen mupt100=mupt*100;

*gen everfired_fireopt=.;
*gen davglength_fireopt=.;

line everfired_tenure everfired_fireavgva everfired_fire everfired_fireopt mupt100,
      xtitle("Percentile of true ability") xlabel(0 (10) 100) 
      ytitle("Fraction ever fired") ylabel(, nogrid)
      legend(subtitle("Firing decision based on:") label(1 "Performance over first 2 years (tenure)") label(2 "Average performance to date") 
             label(3 "Posterior mean ability") label(4 `""Optimal" decision rule"') ring(0) pos(1) cols(1))
      saving(`thisdir'/`dofile'_everfire.gph, replace);
     ;

line davglength_tenure davglength_fireavgva davglength_fire davglength_fireopt mupt100,
      xtitle("Percentile of true ability") xlabel(0 (10) 100) 
      ytitle("% change in career length") ylabel(, nogrid)
      legend(label(1 "Tenure") label(3 "Fire - Posterior mean") label(2 "Fire - Avg. performance")
             label(4 "Fire - Optimal decision rule") ring(0) pos(5) cols(1))
      saving(`thisdir'/`dofile'_davglength.gph, replace);
     ;
line firedate_tenure firedate_fireavgva firedate_fire firedate_fireopt mupt100,
      xtitle("Percentile of true ability") xlabel(0 (10) 100) 
      ytitle("Avg. time to fire (if ever fired)") ylabel(, nogrid)
      legend(label(1 "Tenure") label(3 "Fire - Posterior mean") label(2 "Fire - Avg. performance")
             label(4 "Fire - Optimal decision rule") ring(0) pos(1) cols(1))
      saving(`thisdir'/`dofile'_firedate.gph, replace);
     ;

save `thisdir'/`dofile'.dta, replace;


*And redo for cumulative firing hazards;
 foreach f in fire fireavgva  tenure fireopt {;
  use `scratch'/appendix_altfiringruns_`f'0.dta, clear;
  sort id year;
  gen everfired=fired_ + firedyet_;
  gen mupt=round(normal(mu/`sig_t'), 0.01);
  gen muquart=1 + (mupt>0.25) + (mupt>0.5) + (mupt>0.75) if mupt<.;
  gen mudecile=1 + (mupt>0.1) + (mupt>0.2) + (mupt>0.3) + (mupt>0.4) 
                 + (mupt>0.5) + (mupt>0.6) + (mupt>0.7) + (mupt>0.8) + (mupt>0.9)  if mupt<.;
  recode mudecile (1=1) (2=2) (3/4=3) (5/10=4), gen(declow);
  label define dec 1 "Lowest decile" 2 "Second decile" 3 "Third and fourth deciles" 4 "Deciles five to ten";
  label values declow dec;
  label var declow "ability group";
  collapse (mean) everfired (count) mu, by(declow year);
  rename everfired cumul_`f';
  rename mu n_`f';
  tempfile `f'_cumul;
  save ``f'_cumul';
 };
 drop _all;
 set obs 4;
 gen declow=_n;
  label var declow "ability group";
  label values declow dec;
 gen year=0;
 append using `tenure_cumul';
 merge 1:1 declow year using `fireavgva_cumul', assert(1 3);
 assert year==0 if _merge==1;
 drop _merge;
 merge 1:1 declow  year using `fire_cumul', assert(1 3);
 assert year==0 if _merge==1;
 drop _merge;
 merge 1:1 declow  year using `fireopt_cumul', assert(1 3);
 assert year==0 if _merge==1;
 drop _merge;
 replace cumul_tenure=0    if cumul_tenure==. & year==0;
 replace cumul_fireavgva=0 if cumul_fireavgva==. & year==0;
 replace cumul_fire=0      if cumul_fire==. & year==0;
 replace cumul_fireopt=0   if cumul_fireopt==. & year==0;
 *label define quart 1 "Lowest quartile" 2 "2nd quartile" 3 "3rd quartile" 4 "Top quartile";
 *label values muquart quart;
 *label var muquart "ability quartile";
 label var year "Years of experience";
 line cumul_tenure cumul_fireavgva cumul_fire cumul_fireopt year, 
      by(declow) 
      ytitle("Cumulative fraction fired")
      legend(subtitle("Firing decision based on:") label(1 "First 2 years (tenure)") label(2 "Average performance to date") 
             label(3 "Posterior mean ability") label(4 `""Optimal" decision rule"') cols(2))
      saving(`thisdir'/`dofile'_cumulative.gph, replace);
 save `thisdir'/`dofile'_cumulative.dta, replace;      

****Some statistics for the write-up;
 cap log close paperstats;
 log using "`thisdir'/`dofile'_paperstats.log", text replace name(paperstats);
 *********************************************************************;
 /*My first ongoing firing contract conditions retention on the teacher's 
  *average performance to date: Any t th-year teacher for whom 
  *\bar{y}_{t}\equiv\frac{1}{t}\sum_{s=1}^{t}y_{s}
  *falls below a fixed threshold is fired. I express the thresholds in 
  *terms of the share of the baseline teacher workforce that would be 
  *fired immediately under the policy. For example, when the threshold 
  *is set to -0.26, 6.4% of current teachers would be displaced 
  *immediately. A much larger share of teachers -- in this example, 20% 
  *-- would be displaced at some point before the end of a 30 year career. 
  *##% would be fired after their first years; ##% of those who remain 
  *would be fired after their second years, and ##% after their third 
  *years. Firing rates fall in later years, but never to zero.
  *;
  *My second ongoing firing contract bases retention decisions on the 
  *district's posterior mean of the teacher's ability, 
  *\frac{\sigma_{\tau}^{2}}{t^{-1}\sigma_{\epsilon}^{2}+\sigma_{\tau}^{2}}\bar{y}_{t}.
  *When this contract's threshold is set at a level that would lead 20% 
  *of teachers to be displaced at some point in their careers, ##% of 
  *teachers (given the current ability distribution) are fired after 
  *their first years, ##% of those who remain are fired after their 
  *second years, and ##% after their third years. 
  *;
  *My third contract uses thresholds that vary over time in a way that 
  *is optimal from the district's perspective, ignoring labor supply 
  *responses. This contract displaces only ##% of first year teachers, 
  *##% after their second years, and ## after their third years.
  *;
 */;
  foreach contract in fireavgva fire fireopt {;
  	di "*******CONTRACT: 	`contract'*******";
    use `scratch'/appendix_altfiringruns_`contract'0, clear;
    sort id year;
    by id: gen totva=sum(va);
    gen avgva=totva/year;
    if "`contract'"=="fireavgva" {;
    	su avgva if fired_==1;
      local threshold=r(max);
      gen firednow=(avgva<=`threshold');
    };
    else {;
    	gen firednow=.;
    	forvalues t=1/29 {;
    		su avgva if year==`t' & fired_==1, meanonly;
    		replace firednow=(avgva<=r(max)) if year==`t';
    	};
    };
    replace firednow=0 if year==30;
    *Fired now;
     su firednow [aw=Surv];
    *Ever fired;
     by id: egen everfired=max(firednow);
     su everfired if year==30;
    *Fired hazard by year;
     by id: gen ntimesfired=sum(firednow);
     gen firehazard=firednow if firednow==ntimesfired;
     table year, contents(mean firehazard);
  };
 *********************************************************************;
 log close paperstats;
   
!\rm `scratch'/appendix_altfiringruns_fire0.dta;
!\rm `scratch'/appendix_altfiringruns_fireavgva0.dta;
!\rm `scratch'/appendix_altfiringruns_fireopt0.dta;
!\rm `scratch'/appendix_altfiringruns_tenure0.dta;

if `doasproject'==1 {;
	project, creates("`thisdir'/`dofile'_everfire.gph");
	project, creates("`thisdir'/`dofile'_davglength.gph");
	project, creates("`thisdir'/`dofile'_firedate.gph");
	project, creates("`thisdir'/`dofile'_cumulative.gph");
	project, creates("`thisdir'/`dofile'_cumulative.dta");
	project, creates("`thisdir'/`dofile'.dta");
	project, creates("`thisdir'/`dofile'_paperstats.log");
};
	
