version 12.1

cap project, doinfo
if _rc==0 {  
  project, doinfo
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes
  local doasproject=1

  project, original("`pdir'/subroutines/project_includesubroutines.do")
  project, original("`pdir'/learningmodels/learningmodel_tenure.do")
  project, original("`pdir'/learningmodels/learningmodel_fire.do")
  project, uses("`pdir'/varycontracts/optimalfirethresholds.dta")
  do `pdir'/learningmodels/learningmodel_tenure.do
  do `pdir'/learningmodels/learningmodel_fire.do
}
else {
	clear
	local pdir "~/projects/performancepay/project"
	local dofile "appendix_altfiringruns"
	local sig "Not run as part of project!"
  local doasproject=0
}
set more off
include `pdir'/subroutines/project_includesubroutines.do
local thisdir "`pdir'/appendix"

#delimit;

if `doasproject'==1 {;
  project, uses("`pdir'/scratch/drawsamp.dta");
};
 
*Internal subroutines;
 cap program drop savefile;
 program savefile;
   args filename;
   cap ! \rm `filename'.dta.gz;
   save `"`filename'"', replace;
   ! gzip `filename'.dta;
 end;
 
*Set parameters that will be used for all calls by this program;
 local filebase `"`pdir'/scratch/`dofile'"';
 local tableout `"`dofile'_table.txt"';
 local parms0 `"elast_entry(1) elast_exit(1) fireeffect("(-0.01*min(exper,10))") h(0.1) crra(0) crra_type("none")"';
 local parms1 `"elast_entry(0.5) elast_exit(0.5) fireeffect("-0.15") h(0.05) crra(3) crra_type("cashinhand") "';
 local parms2 `"elast_entry(1.5) elast_exit(1.5) fireeffect("(-0.01*min(exper,5))") h(0.25) crra(0) crra_type("none")"';
 local simulparms `"gridpts(149) simulobs(200000) startwage(1)"';


*Prepare the sample that will be used throughout;
 tempfile samp0 samp1 samp2;
 sub_makesamp, basesamp(`pdir'/scratch/drawsamp) `parms0' `simulparms';
 save `samp0', ;
/*
 sub_makesamp, basesamp(`pdir'/scratch/drawsamp) `parms1' `simulparms';
 save `samp1', ;
 sub_makesamp, basesamp(`pdir'/scratch/drawsamp) `parms2' `simulparms';
 save `samp2', ;
*/


*Under tenure contract, 20% of teachers are ever fired.  What about others?;
*First, figure out mapping from frfired to threshold;
 matrix thresholds_avgva=J(40,3,0);
 matrix colnames thresholds_avgva=Frfired Threshold Freverfired;
 matrix thresholds_posterior=thresholds_avgva;
 forvalues f=1/40 {;
 	 local fr=`f'/200;
 	 sub_findthresholds, ctype("fire") gridpts(149) sigma_mu(0.15) sigma_e(0.1837117307087384) maxt(30) expadjust(1)
 	                     basehazard("0.08") var_e(0.03375) var_mu(0.0225)
 	                     frfired(`fr') expeffect(`"-0.07*(exper==0)-0.04*(exper==1)-0.02*(exper==2)"')
 	                     firerule("avgva");
   matrix thresholds_avgva[`f',1]=`fr';
   matrix thresholds_avgva[`f',2]=r(firethreshold);
 	 sub_findthresholds, ctype("fire") gridpts(149) sigma_mu(0.15) sigma_e(0.1837117307087384) maxt(30) expadjust(1)
 	                     basehazard("0.08") var_e(0.03375) var_mu(0.0225)
 	                     frfired(`fr') expeffect(`"-0.07*(exper==0)-0.04*(exper==1)-0.02*(exper==2)"')
 	                     firerule("posterior");
   matrix thresholds_posterior[`f',1]=`fr';
   matrix thresholds_posterior[`f',2]=r(firethreshold);
 };

*And figure out thresholds, in order, for optimal firing rules;
 use if t==1 using `pdir'/varycontracts/optimalfirethresholds, clear;
 gsort frfired;
 gen freverfired=0;
 mkmat num frfired freverfired, matrix(thresholds_optimal);
 su num, meanonly;
 local numoptruns=r(N);
 
*Now, figure out fraction who are ever fired using each threshold;
 use `samp0', clear;
 drop e* va* prior* g_*;
 local var_mu=0.0225;
 local var_e=0.03375;
 forvalues t=1/30 {;
 	 gen dprior`t'=avgva`t'*`var_mu'/(`var_mu' + (`var_e'/`t'));
 };

 forvalues f=1/40 {;
 	 local t_avgva=el(thresholds_avgva, `f', 2);
 	 local t_posterior=el(thresholds_posterior, `f', 2);
 	 *gen freverfired_avgva=0;
 	 gen firedate_avgva=0;
 	 gen firedate_posterior=0;
 	 forvalues t=1/29 {;
 	 	 replace firedate_avgva=`t' if avgva`t'<`t_avgva' & firedate_avgva==0;
 	 	 replace firedate_posterior=`t' if dprior`t'<`t_posterior' & firedate_posterior==0;
 	 };
 	 gen everfired_avgva=(firedate_avgva>0);
 	 gen everfired_posterior=(firedate_posterior>0);
 	 su everfired_avgva, meanonly;
 	 matrix thresholds_avgva[`f',3]=r(mean);
 	 su everfired_posterior, meanonly;
 	 matrix thresholds_posterior[`f',3]=r(mean);
 	 drop firedate_* everfired_*;
 };
 matrix list thresholds_avgva;
 matrix list thresholds_posterior;

 *And do the same thing for the optimal firing rule;
  forvalues f=1/`numoptruns' {;
  	local optnum = el(thresholds_optimal, `f', 1);
  	use if num==`optnum' using `pdir'/varycontracts/optimalfirethresholds, clear;
    sort t;
  	mkmat c, matrix(cmat);
    use `samp0', clear;
    local var_mu=0.0225;
    local var_e=0.03375;
  	gen firedate_avgva=0;
 	  forvalues t=1/29 {;
 	 	 replace firedate_avgva=`t' if avgva`t'<el(cmat, `t', 1) & firedate_avgva==0;
 	  };
  	gen everfired_avgva=(firedate_avgva>0);
 	  su everfired_avgva, meanonly;
 	  matrix thresholds_optimal[`f',3]=r(mean);
  	drop firedate_* everfired_*;
 };
 matrix list thresholds_optimal;
 
 *Find firing threshold that gets rid of approximately 20%;
  local f_avgva=0;
  local f_posterior=0;
  local n_optimal=0;
  local f_optimal=0;

  forvalues f=1/40 {;
  	local e=`f'-1;
    if el(thresholds_avgva,`f',3)>0.2 & `f_avgva'==0 {;
    	if `f'==1 local f_avgva=el(thresholds_avgva,`f',1)*(0.2/el(thresholds_avgva,`f',3));
    	else {;
    		local f_avgva=el(thresholds_avgva, `e',1) + 
    		       (el(thresholds_avgva, `f',1) -el(thresholds_avgva, `e',1))*
    		       (0.2 - el(thresholds_avgva, `e', 3))/(el(thresholds_avgva, `f',3) -el(thresholds_avgva, `e',3));
      };
      di "Avg VA firing rate is `f_avgva'";
    };
    if el(thresholds_posterior,`f',3)>0.2 & `f_posterior'==0 {;
    	if `f'==1 local f_posterior=el(thresholds_posterior,`f',1)*(0.2/el(thresholds_posterior,`f',3));
    	else {;
    		local f_posterior=el(thresholds_posterior, `e',1) + 
    		       (el(thresholds_posterior, `f',1) -el(thresholds_posterior, `e',1))*
    		       (0.2 - el(thresholds_posterior, `e', 3))/(el(thresholds_posterior, `f',3) -el(thresholds_posterior, `e',3));
      };
      di "Avg posterior mean firing rate is `f_posterior'";
    };
  };

  forvalues n=1/`numoptruns' {;
  	local m=`n'-1;
    if el(thresholds_optimal,`n',3)>0.2 & `n_optimal'==0 {;
    	if `n'==1 | el(thresholds_optimal, `n', 3)-0.2 < 0.2 - el(thresholds_optimal, `m', 3) {; 
    	   local n_optimal=el(thresholds_optimal, `n', 1);
    	   local f_optimal=el(thresholds_optimal, `n', 3);
    	 };
    	 else {;
    	   local n_optimal=el(thresholds_optimal, `m', 1);
    	   local f_optimal=el(thresholds_optimal, `m', 3);
    	 };
      di "Optimal firing rate is `f_optimal', for run number `n_optimal'";
    };
  };

  	
 
*Now run each contract;
 *Tenure after two years;
   runmodel using `samp0', ctype("tenure") frtenured(0.8) name("tenure0") 
                           `parms0' `simulparms';
   savefile `filebase'_tenure0;
   
   
  *Fired based on posterior mean;
   runmodel using `samp0', ctype("fire") frfired(`f_posterior') name("fire0") 
                           `parms0' `simulparms';
   savefile `filebase'_fire0;
  *Fired based on avg VA; 
   runmodel using `samp0', ctype("fire") firerule("avgva") frfired(`f_avgva') name("fireavg0") 
                           `parms0' `simulparms';
   savefile `filebase'_fireavgva0;
  *Fired based on optimal decision - row 12 has a firing rate of 20.3%;
   use if num==`n_optimal' using `pdir'/varycontracts/optimalfirethresholds, clear;
   sort t;
 	 mkmat c, matrix(cmat);
   matrix list cmat;
   su frfired, meanonly;
   local ff=r(mean);
   su firecost, meanonly;
   local fc=r(mean);
   runmodel using `samp0', ctype("fire") firerule("matrix") firemat(cmat) name("fireopt0")
                           `parms0' `simulparms';
   savefile `filebase'_fireopt0;

if `doasproject'==1 {;
  project, creates("`filebase'_tenure0.dta.gz");
  project, creates("`filebase'_fire0.dta.gz");
  project, creates("`filebase'_fireavgva0.dta.gz");
  project, creates("`filebase'_fireopt0.dta.gz");
};
   
