
*Make a graph of the exit hazard using 1999-2000 SASS/TFS data (public use)
*
*Note: Raw data come from the NCES EDAT tool. See the included readme.txt
*file (in the rawdata/sasstfs directory) for instructions about how to re-
*download them.


version 12.1
set scheme lean1

cap project, doinfo
if _rc==0 {  
	local doasproject=1
  project, doinfo
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

  project, original("`pdir'/rawdata/sasstfs/SASS_99_00_S4a_v1_0.dta.gz")
  project, original("`pdir'/rawdata/sasstfs/SASS_99_00_T2_v1_0.dta.gz")
  project, original("`pdir'/rawdata/sasstfs/SASS_99_00_T3_v1_0.dta.gz")
  project, relies_on("`pdir'/rawdata/sasstfs/readme.txt")
  project, relies_on("`pdir'/rawdata/sasstfs/SASS_99_00_S1A_v1_0_Codebook.txt.gz")
  project, relies_on("`pdir'/rawdata/sasstfs/SASS_99_00_S1A_v1_0_S4A_Layout.txt.gz")
  project, relies_on("`pdir'/rawdata/sasstfs/SASS_99_00_S1A_v1_0_T2_Layout.txt.gz")
  project, relies_on("`pdir'/rawdata/sasstfs/SASS_99_00_S1A_v1_0_T3_Layout.txt.gz")
}
else {
	local doasproject=0
	local pdir "~/projects/performancepay/project"
	local dofile "appendix_exithazard"
	local sig "Not run as part of project!"
	clear
}
local thisdir "`pdir'/appendix"
local sassdir "`pdir'/rawdata/sasstfs"
local scratch "`pdir'/scratch"
if c(os)=="MacOSX" local zcatcmd "gzcat"
else local zcatcmd "zcat"

! `zcatcmd' `sassdir'/SASS_99_00_S4a_v1_0.dta.gz > `scratch'/SASS_99_00_S4a_v1_0.dta
! `zcatcmd' `sassdir'/SASS_99_00_T2_v1_0.dta.gz > `scratch'/SASS_99_00_T2_v1_0.dta
! `zcatcmd' `sassdir'/SASS_99_00_T3_v1_0.dta.gz > `scratch'/SASS_99_00_T3_v1_0.dta

#delimit;

/* Open Stata dataset */
use "`scratch'/SASS_99_00_S4a_v1_0";

/* Keep only selected variables */
keep
   TOTEXPER
   TREPWT1
   TREPWT10
   TREPWT11
   TREPWT12
   TREPWT13
   TREPWT14
   TREPWT15
   TREPWT16
   TREPWT17
   TREPWT18
   TREPWT19
   TREPWT2
   TREPWT20
   TREPWT21
   TREPWT22
   TREPWT23
   TREPWT24
   TREPWT25
   TREPWT26
   TREPWT27
   TREPWT28
   TREPWT29
   TREPWT3
   TREPWT30
   TREPWT31
   TREPWT32
   TREPWT33
   TREPWT34
   TREPWT35
   TREPWT36
   TREPWT37
   TREPWT38
   TREPWT39
   TREPWT4
   TREPWT40
   TREPWT41
   TREPWT42
   TREPWT43
   TREPWT44
   TREPWT45
   TREPWT46
   TREPWT47
   TREPWT48
   TREPWT49
   TREPWT5
   TREPWT50
   TREPWT51
   TREPWT52
   TREPWT53
   TREPWT54
   TREPWT55
   TREPWT56
   TREPWT57
   TREPWT58
   TREPWT59
   TREPWT6
   TREPWT60
   TREPWT61
   TREPWT62
   TREPWT63
   TREPWT64
   TREPWT65
   TREPWT66
   TREPWT67
   TREPWT68
   TREPWT69
   TREPWT7
   TREPWT70
   TREPWT71
   TREPWT72
   TREPWT73
   TREPWT74
   TREPWT75
   TREPWT76
   TREPWT77
   TREPWT78
   TREPWT79
   TREPWT8
   TREPWT80
   TREPWT81
   TREPWT82
   TREPWT83
   TREPWT84
   TREPWT85
   TREPWT86
   TREPWT87
   TREPWT88
   TREPWT9
   CNTLNUM
   SCHCNTL
   TFNLWGT
   ;

/* Display descriptives for the continuous variables */
summarize
      TOTEXPER
      CNTLNUM
      SCHCNTL
      ;

*DROP REPLICATE WEIGHTS;
 drop TREPWT*;
 foreach v of varlist TOTEXPER SCHCNTL TFNLWGT {;
 	 rename `v' sass_`v';
 };
/* Compress the data to save space */
compress;

/* Save dataset */
tempfile mainsass;
save `mainsass';
*save "SASS_99_00_S4A_v1_0_120425112412", replace;


/* Clear everything */
clear;

/* Open Stata dataset */
use "`scratch'/SASS_99_00_T2_v1_0";

/* Keep only selected variables */
keep
   F0050
   F0051
   F0053
   F0056
   F0060
   TOTEXP_T
   TOTEXPER
   CNTLNUM
   SCHCNTL
   TFRPWT20
   TFRPWT21
   TFRPWT22
   TFRPWT1
   TFRPWT10
   TFRPWT11
   TFRPWT12
   TFRPWT13
   TFRPWT14
   TFRPWT15
   TFRPWT16
   TFRPWT17
   TFRPWT18
   TFRPWT19
   TFRPWT2
   TFRPWT23
   TFRPWT24
   TFRPWT25
   TFRPWT26
   TFRPWT27
   TFRPWT28
   TFRPWT29
   TFRPWT3
   TFRPWT30
   TFRPWT31
   TFRPWT32
   TFRPWT33
   TFRPWT34
   TFRPWT35
   TFRPWT36
   TFRPWT37
   TFRPWT38
   TFRPWT39
   TFRPWT4
   TFRPWT40
   TFRPWT41
   TFRPWT42
   TFRPWT43
   TFRPWT44
   TFRPWT45
   TFRPWT46
   TFRPWT47
   TFRPWT48
   TFRPWT49
   TFRPWT5
   TFRPWT50
   TFRPWT51
   TFRPWT52
   TFRPWT53
   TFRPWT54
   TFRPWT55
   TFRPWT56
   TFRPWT57
   TFRPWT58
   TFRPWT59
   TFRPWT6
   TFRPWT60
   TFRPWT61
   TFRPWT62
   TFRPWT63
   TFRPWT64
   TFRPWT65
   TFRPWT66
   TFRPWT67
   TFRPWT68
   TFRPWT69
   TFRPWT7
   TFRPWT70
   TFRPWT71
   TFRPWT72
   TFRPWT73
   TFRPWT74
   TFRPWT75
   TFRPWT76
   TFRPWT77
   TFRPWT78
   TFRPWT79
   TFRPWT8
   TFRPWT80
   TFRPWT81
   TFRPWT82
   TFRPWT83
   TFRPWT84
   TFRPWT85
   TFRPWT86
   TFRPWT87
   TFRPWT88
   TFRPWT9
   TFSFINWT
   ;
drop TFRPWT*;

/* Display frequencies for the categorical variables */
tabulate F0050;
tabulate F0051;
tabulate F0053;
/* Display descriptives for the continuous variables */
summarize
      TOTEXP_T
      TOTEXPER
      CNTLNUM
      SCHCNTL
      ;

/* Compress the data to save space */
compress;
foreach v of varlist F0050 F0051 F0053 F0056 F0060 TOTEXP_T TOTEXPER SCHCNTL TFSFINWT {;
 	 rename `v' tfs1_`v';
 };

/* Save dataset */
tempfile tfs1;
save `tfs1';
*save "SASS_99_00_T2_v1_0_120425112412", replace;


/* Clear everything */
clear;

/* Open Stata dataset */
use "`scratch'/SASS_99_00_T3_v1_0";

/* Keep only selected variables */
keep
   TOTEXP_T
   TOTEXPER
   F0050
   SCHCNTL
   CNTLNUM
   TFRPWT2
   TFRPWT20
   TFRPWT21
   TFRPWT1
   TFRPWT10
   TFRPWT11
   TFRPWT12
   TFRPWT13
   TFRPWT14
   TFRPWT15
   TFRPWT16
   TFRPWT17
   TFRPWT18
   TFRPWT19
   TFRPWT22
   TFRPWT23
   TFRPWT24
   TFRPWT25
   TFRPWT26
   TFRPWT27
   TFRPWT28
   TFRPWT29
   TFRPWT3
   TFRPWT30
   TFRPWT31
   TFRPWT32
   TFRPWT33
   TFRPWT34
   TFRPWT35
   TFRPWT36
   TFRPWT37
   TFRPWT38
   TFRPWT39
   TFRPWT4
   TFRPWT40
   TFRPWT41
   TFRPWT42
   TFRPWT43
   TFRPWT44
   TFRPWT45
   TFRPWT46
   TFRPWT47
   TFRPWT48
   TFRPWT49
   TFRPWT5
   TFRPWT50
   TFRPWT51
   TFRPWT52
   TFRPWT53
   TFRPWT54
   TFRPWT55
   TFRPWT56
   TFRPWT57
   TFRPWT58
   TFRPWT59
   TFRPWT6
   TFRPWT60
   TFRPWT61
   TFRPWT62
   TFRPWT63
   TFRPWT64
   TFRPWT65
   TFRPWT66
   TFRPWT67
   TFRPWT68
   TFRPWT69
   TFRPWT7
   TFRPWT70
   TFRPWT71
   TFRPWT72
   TFRPWT73
   TFRPWT74
   TFRPWT75
   TFRPWT76
   TFRPWT77
   TFRPWT78
   TFRPWT79
   TFRPWT8
   TFRPWT80
   TFRPWT81
   TFRPWT82
   TFRPWT83
   TFRPWT84
   TFRPWT85
   TFRPWT86
   TFRPWT87
   TFRPWT88
   TFRPWT9
   TFSFINWT
   ;
drop TFRPWT*;
/* Display frequencies for the categorical variables */
tabulate F0050;
/* Display descriptives for the continuous variables */
summarize
      TOTEXP_T
      TOTEXPER
      CNTLNUM
      SCHCNTL
      ;

foreach v of varlist F0050 TOTEXP_T TOTEXPER SCHCNTL TFSFINWT {;
	rename `v' tfs2_`v';
};
/* Compress the data to save space */
compress;

/* Save dataset */
tempfile tfs2;
save `tfs2';
*save "SASS_99_00_T3_v1_0_120425112412", replace;


use `mainsass';
merge 1:1 CNTLNUM using `tfs1';
rename _merge mrg1;
gen origin=100 if mrg1==1;
replace origin=10 if mrg1==2;
replace origin=110 if mrg1==3;

merge 1:1 CNTLNUM using `tfs2';
rename _merge mrg2;
tab mrg1 mrg2, m;
replace origin=1 if mrg2==2;
replace origin=origin+1 if mrg2==3;

gen tfswgt=tfs1_TFSFINWT if origin==110;
replace tfswgt=tfs2_TFSFINWT if origin==101;
gen exited=(origin==110) if origin==110 | origin==101;
tab exited [aw=tfswgt];
*Excludes those who are caring for a family member and plan to return to the classroom;
gen exited2=exited;
replace exited2=0 if exited<. & tfs1_F0053==5 & tfs1_F0060==1;
*Excludes those working outside the classroom but in el/sec education, for state/local govt;
gen exited3=exited2;
replace exited3=0 if exited<. & tfs1_F0053==1 & inlist(tfs1_F0056, 3, 4);

recode sass_TOTEXPER (0/4=1) (5/9=2) (10/14=3) (15/19=4) (20/24=5) (25/29=6) (30/max=7), gen(expcat);
table expcat [aw=tfswgt], contents(mean exited mean exited2 mean exited3 count exited);

su exited exited2 exited3 [aw=tfswgt];
su exited exited2 exited3 if sass_TOTEXPER<30 [aw=tfswgt];
su exited exited2 exited3 if sass_TOTEXPER>=5 & sass_TOTEXPER<30 [aw=tfswgt];

collapse (mean) exited exited2 exited3 (count) origin (rawsum) totwgt=tfswgt if exited<. [aw=tfswgt], by(sass_TOTEXPER);


gen althazard=0.06 - 0.03*(sass_TOTEXPER>=5) if sass_TOTEXPER<=30;

line exited exited3 althazard sass_TOTEXPER  if sass_TOTEXPER<40, xtitle("Years of experience")
     ytitle("Attrition rate")
     yline(0.08) xline(30)
     legend(label(1 "All exits from classroom") label(2 "Exclude family leave, administration")
            ring(0) pos(11) cols(1) order(1 2))
     saving(`thisdir'/`dofile'.gph, replace);

! \rm `scratch'/SASS_99_00_S4a_v1_0.dta;
! \rm `scratch'/SASS_99_00_T2_v1_0.dta;
! \rm `scratch'/SASS_99_00_T3_v1_0.dta;

if `doasproject'==1 project, creates(`thisdir'/`dofile'.gph);
     
