version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

  project, uses("`pdir'/scratch/models_table2_tenure_fixedN.dta.gz")
  project, uses("`pdir'/scratch/models_table2_bonus_fixedN.dta.gz")
}
else {
	local doasproject=0
	local pdir "~/projects/performancepay/project"
  local dofile "gph_careerlength"
	local sig "Not run as part of project!"
}
local thisdir "`pdir'/figures"
local scratch "`pdir'/scratch"
#delimit;

clear;
set more off;
set scheme lean1;

local sig_t=0.15;
if c(os)=="MacOSX" local zcatcmd "gzcat";
else local zcatcmd "zcat";

cap program drop smooth4;
program define smooth4;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(4*`origvar' 
                       + 3*(`origvar'[_n-1] + `origvar'[_n+1])
                       + 2*(`origvar'[_n-2] + `origvar'[_n+2])
                       + 1*(`origvar'[_n-3] + `origvar'[_n+3]))/16
            if _n>3 & _n<_N-2;
 `bytxt' replace `newvar'=(3*`origvar' 
                           + 2*(`origvar'[_n-1] + `origvar'[_n+1])
                           + 1*(`origvar'[_n-2] + `origvar'[_n+2]))/9
            if _n==3 | _n==_N-2;
 `bytxt' replace `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n==2 | _n==_N-1;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            


*A program to smooth series;
cap program drop smooth3;
program define smooth3;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(3*`origvar' 
                           + 2*(`origvar'[_n-1] + `origvar'[_n+1])
                           + 1*(`origvar'[_n-2] + `origvar'[_n+2]))/9
            if _n>2 | _n<_N-1;
 `bytxt' replace `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n==2 | _n==_N-1;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            

*A program to smooth series;
cap program drop smooth2;
program define smooth2;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n>1 & _n<_N;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            

  
foreach policy in bonus tenure {;
 cap confirm `scratch'/models_table2_`policy'_fixedN.dta;
 if _rc==0 {;
 	 cap confirm `scratch'/models_table2_`policy'_fixedN.dta.gz;
 	 if _rc==0 {;
 	 	 !\rm `scratch'/models_table2_`policy'_fixedN.dta;
 	 	 !`zcatcmd' `scratch'/models_table2_`policy'_fixedN.dta.gz > `scratch'/models_table2_`policy'_fixedN.dta;
 	 };
 };
 else !`zcatcmd' `scratch'/models_table2_`policy'_fixedN.dta.gz > `scratch'/models_table2_`policy'_fixedN.dta;

	use `scratch'/models_table2_`policy'_fixedN, clear;
  sort id year;
  by id: gen survwgt_base=Surv-Surv[_n+1];
  by id: replace survwgt_base=Surv if _n==_N;
  by id: gen survwgt_policy=Surv_policy-Surv_policy[_n+1];
  by id: replace survwgt_policy=Surv_policy if _n==_N;
  replace survwgt_policy=survwgt_policy*entryweight;
  cap confirm var firedyet_;
  if _rc==0 gen survwgt_policy_alt=survwgt_base*(firedyet_==0);
  else gen survwgt_policy_alt=survwgt_base;
  gen mupt=round(normal(mu/`sig_t'), 0.01);
  gen yearwgt_base=year*survwgt_base;
  gen yearwgt_policy=year*survwgt_policy;
  gen yearwgt_policy_alt=year*survwgt_policy_alt;
  collapse (sum) yearwgt_base yearwgt_policy yearwgt_policy_alt survwgt_base survwgt_policy survwgt_policy_alt (mean) mu, by(mupt);
  gen avglength_base=yearwgt_base/survwgt_base;
  gen avglength_policy=yearwgt_policy/survwgt_policy;
  gen avglength_policy_alt=yearwgt_policy_alt/survwgt_policy_alt;
  smooth3, newvar(avglength_`policy') origvar(avglength_policy);
  smooth3, newvar(avglength_`policy'_alt) origvar(avglength_policy_alt);
  keep mu mupt avglength_base avglength_`policy' avglength_`policy'_alt;
  sort mupt;
  tempfile avglength`policy';
  gen davglength_`policy'=100*(avglength_`policy'/avglength_base)-100;
  gen davglength_`policy'_alt=100*(avglength_`policy'_alt/avglength_base)-100;
  gen mupt100=mupt*100;
  keep mupt100 davglength_`policy' davglength_`policy'_alt avglength_`policy' avglength_base;
  tempfile avglength`policy';
  save `avglength`policy'';
  
  
};
use `avglengthbonus';
merge 1:1 mupt100 using `avglengthtenure';
drop _merge;
*line davglength_bonus davglength_tenure davglength_tenure_alt mupt100,
      xtitle("Percentile of true ability") xlabel(0 (10) 100) 
      ytitle("Change in avg. career length (%)") yline(0, lcolor(gray)) ylabel(, nogrid)
      legend(label(1 "Bonus") label(2 "Tenure") label(3 "Tenure (no behavioral response)") ring(0) pos(3) cols(1))
      saving(`dofile'.gph, replace);
line davglength_bonus davglength_tenure mupt100,
      xtitle("Percentile of true ability") xlabel(0 (10) 100) 
      ytitle("Change in avg. career length (%)") yline(0, lcolor(gray)) ylabel(, nogrid)
      legend(label(1 "Bonus") label(2 "Tenure") ring(0) pos(3) cols(1))
      saving(`thisdir'/`dofile'.gph, replace);
 
 save `thisdir'/`dofile'.dta, replace;
      
!\rm `scratch'/models_table2_tenure_fixedN.dta;
!\rm `scratch'/models_table2_bonus_fixedN.dta;

****Some statistics for the write-up;
 cap log close paperstats;
 log using "`thisdir'/`dofile'_paperstats.log", text replace name(paperstats);
 *********************************************************************;
 *The 1-\alpha^{B}=3.5\%# cut to baseline salaries under this contract 
 *reduces career lengths of below-median teachers by only about #5%.
 *;
  su davglength_bonus if mupt100<50;
  list mupt100 avglength_base avglength_bonus davglength_bonus
       if abs(mupt100 - 10*floor(mupt100/10))<0.1;
 *********************************************************************;
 /*The tenure contract has a more dramatic effect. Career lengths shorten
 *by as much as 80% for the very weakest teachers. This primarily reflects
 *tenure denials. Among slightly higher ability teachers, around the 20th 
 *percentile, career lengths shorten by an average of about 30%. The change 
 *would be only about half this large in the absence of labor supply 
 *responses; the other half comes from voluntary exits after the first 
 *year among teachers who have learned their tenure chances are low. At 
 *the other end of the distribution, careers lengthen by about #%, as 
 *higher salaries reduce voluntary attrition among tenured teachers. 
 */;
  list mupt100 avglength_base avglength_tenure davglength_tenure
       davglength_tenure_alt
       if abs(mupt100 - 10*floor(mupt100/10))<0.1;
 *;
 *********************************************************************;
 log close paperstats;

if `doasproject'==1 project, creates("`thisdir'/`dofile'.gph");
if `doasproject'==1 project, creates("`thisdir'/`dofile'.dta");
if `doasproject'==1 project, creates("`thisdir'/`dofile'_paperstats.log");
      
