version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

  project, original("`pdir'/subroutines/sub_valfn.do")
  project, original("`pdir'/subroutines/sub_baselineparms.do")
  project, uses("`pdir'/scratch/models_table2_tenure_fixedN.dta.gz")
  project, uses("`pdir'/scratch/models_table2_bonus_fixedN.dta.gz")
}
else {
	local doasproject=0
	local pdir "~/projects/performancepay/project"
  local dofile "gph_equivalentvariation"
	local sig "Not run as part of project!"
}
local thisdir "`pdir'/figures"
local scratch "`pdir'/scratch"
#delimit;

qui do `pdir'/subroutines/sub_baselineparms;
qui do `pdir'/subroutines/sub_valfn;

clear;
set more off;
set scheme lean1;

local h=0.4;
local sig_t=0.15;
local sig_e=sqrt(1.5)*`sig_t';
local sig2_t=`sig_t'^2;
local sig2_e=(`sig_e'^2)/2;
local sig_e=sqrt(`sig2_e');
local sig2_mu=`h'*`sig2_t';
local sig2_v=`sig2_t' - `sig2_mu';
local bonusthreshold=.1779762655496597;

 local parms `"elast_entry(1) elast_exit(1) fireeffect("(-0.01*min(exper,10))") h(0.1) crra(0) crra_type("none")"';
 local simulparms `"gridpts(149) simulobs(200000) store searchwage"';

if c(os)=="MacOSX" local zcatcmd "gzcat";
else local zcatcmd "zcat";

*A program to compute values under baseline contracts for various changes in base wages;
cap program drop baseval;
program define baseval;
syntax, w0(numlist)
        [/*Teacher career parameters*/
           basehazard(real 0.08) maxt(real 30) expreturn(real 0.015) fixedcost_base(real 0) fixedcost_policy(real 0)
         /*Teacher effectiveness parameters*/
           sigma_mu(real 0.15) expeffect(string) h(real 0.25) corrtruth(real 1)
         /*Performance measures*/
           rsignal(real 0.4)
         /*Contract type*/
           ctype(string)
         /*Bonus policy*/
           frbonus(real 0.25) bonussize(real 0.2) expadjust(real 1) 
         /*Continuous performance pay policy*/
           ppayslope(real 0.15)
         /*Firing policy*/
           frfired(real 0.1) fireeffect(string) firerule(string) firemat(name)
         /*Tenure policy*/
           frtenured(real 0.8) tenuredate(real 2) 
         /*Preference parameters*/
           crra(real 3) crra_type(string) discount(real 0.03) elast_exit(string) elast_entry(string) maxwage(real 2)
         /*Simulation parameters*/
           gridpts(integer 49) simulobs(integer 50000) startwage(real -1) tol(real 0.0001)
          * ];
  *Set defaults for non-numeric parameters;         
    if `"`expeffect'"'==`""' local expeffect="-0.07*(exper==0)-0.04*(exper==1)-0.02*(exper==2)";
    if `"`ctype'"'==`""' local ctype="bonus";
    if `"`crra_type'"'==`""' local crra_type="none";
    if `"`crra_type'"'==`"none"' local crra=0;
    if (`fixedcost_base'>0 | `fixedcost_policy'>0) & `"`crra_type'"'~="none" {;
    	di "Programs cant accommodate a fixed cost of entry with nonlinear vN-M utility";
    	err;
    };
    if `"`basehazard'"'==`""' local basehazard="0.08";
    if `"`elast_entry'"'==`""' local elast_entry="3";
    if `"`elast_exit'"'==`""' local elast_exit="3";
    if `"`fireeffect'"'==`""' local fireeffect="-0.1";
    if `"`criteria'"'==`""' local criteria="numteach";
    if `"`firerule'"'==`""' local firerule="posterior";
 

  drop _all;
  clear;
  clear results;
  
  local baseopts `"ctype(`"`ctype'"')"';
  local baseopts `"`baseopts' basehazard(`"`basehazard'"') maxt(`maxt') expreturn(`expreturn') fixedcost_base(`fixedcost_base') fixedcost_policy(`fixedcost_policy')"';
  local baseopts `"`baseopts' sigma_mu(`sigma_mu') expeffect(`"`expeffect'"') h(`h') corrtruth(`corrtruth')"';
  local baseopts `"`baseopts' rsignal(`rsignal')"';
  local baseopts `"`baseopts' frbonus(`frbonus') bonussize(`bonussize') expadjust(`expadjust')"';
  local baseopts `"`baseopts' ppayslope(`ppayslope')"';
  local baseopts `"`baseopts' frfired(`frfired') fireeffect(`"`fireeffect'"') firerule(`"`firerule'"') firemat(`firemat')"';
  local baseopts `"`baseopts' frtenured(`frtenured') tenuredate(`tenuredate')"';
  local baseopts `"`baseopts' crra(`crra') crra_type(`"`crra_type'"') discount(`discount') elast_exit(`"`elast_exit'"') elast_entry(`"`elast_entry'"') maxwage(`maxwage')"';
  local baseopts `"`baseopts' gridpts(`gridpts') simulobs(`simulobs') startwage(`startwage') tol(`tol') `searchwage' criteria(`"`criteria'"')"';

  *Some calculations;
    local var_mu=`sigma_mu'^2;
    local var_e=`var_mu'*(1-`rsignal')/`rsignal';
    local sigma_e=sqrt(`var_e');
    local var_sig=`var_mu'+`var_e';
    local sigma_sig=sqrt(`var_sig');
    local priorvar0=`var_mu'*(1-`h');
    local var_prior0=`var_mu'*`h';


 *First, figure out the baseline parameters, using the base contract.;
   qui sub_baselineparms, `baseopts';
   foreach item in sdeffect_base vareffect_base avgeffect_base meanwage_base nteach_base initialvalue elast_valwage avgelast {;
   	 local `item'=r(`item');
   	 local baseparms `"`baseparms' `item'(``item'')"';
   	 di "`item' = ``item''";
   	 *return scalar `item'=``item'';
   };
   matrix etaexit=r(eta_exit);
   matrix valfired=r(val_fired);
  *Extract the c and eta parameters;
   forvalues t=2/`maxt' {;
  	 local eta`t'=el(etaexit, `t', 2);
  	 local c`t'=el(etaexit, `t', 3);
   };

   local runthrough=1;
   qui {;
   foreach w of numlist `w0' {;
   	 matrix onecol=J(1, `maxt', 0);
   	 matrix rownames onecol=w`runthrough';
     drop _all;
     set obs 1;
     gen wage_policy=`w'*((1+`expreturn')^(`maxt'-1));
     sub_valfn, crra(`crra') etanext(0) next(`maxt') basehazard(`basehazard') cnext(0)
                maxwage(`maxwage') discount(`discount') crra_type(`crra_type') lastperiod;
     su valfn_`maxt', meanonly;           
     matrix onecol[1, `maxt']=r(mean);
     forvalues n=2/`maxt' {;
   	   local t=`maxt'-`n'+1;
   	   local next=`t'+1;
   	   replace wage_policy=`w'*((1+`expreturn')^(`t'-1));
       sub_valfn, crra(`crra') etanext(`eta`next'') next(`next') basehazard(`basehazard') cnext(`c`next'')
                  maxwage(`maxwage') discount(`discount') crra_type(`crra_type');
       su valfn_`t', meanonly;           
       matrix onecol[1, `t']=r(mean);
     };
     matrix onecol=`w', onecol;
     if `runthrough'==1 matrix basevals=onecol;
     else matrix basevals=basevals \ onecol;
     local runthrough=`runthrough'+1;
   };
 };
 *Name matrix columns;
  forvalues t=1/`maxt' {;
  	local tlist "`tlist' val`t'";
  };
  matrix colnames basevals=w0 `tlist';
end;

*A program to assign wage equivalents to values obtained under alternative contracts;
cap program drop assignw;
program define assignw;
  syntax, bvals(name) [tlist(numlist)];
  gen equivw=.;
  if "`tlist'"=="" local tlist="1/30";
  local ncells=rowsof(`bvals')-1;
  foreach t of numlist `tlist' {;
  	su valfn_ if year==`t', meanonly;
	  local maxv=r(max);
	  local minv=r(min);
	  local foundcells=0;
    forvalues c=1/`ncells' {;
	    local lowerw=el(basevals, `c', 1);
	    local upperw=el(basevals, `c'+1, 1);
		  local lower=el(basevals, `c', `t'+1);
		  local upper=el(basevals, `c'+1, `t'+1);
		  if `lower'<=`maxv' & `upper'>=`minv' {;
	      qui gen fr=(valfn_-`lower')/(`upper'-`lower') if year==`t' & valfn_>=`lower' & valfn_<=`upper';
  	    qui replace equivw=`lowerw' + fr*(`upperw'-`lowerw') if fr<.;
  	    drop fr;
  	    local foundcells=`foundcells'+1;
  	  };
	  };
 	  di "At t=`t', there were `foundcells' relevant cells";
  };
end;  

*A program to smooth series;
cap program drop smooth4;
program define smooth4;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(4*`origvar' 
                       + 3*(`origvar'[_n-1] + `origvar'[_n+1])
                       + 2*(`origvar'[_n-2] + `origvar'[_n+2])
                       + 1*(`origvar'[_n-3] + `origvar'[_n+3]))/16
            if _n>3 & _n<_N-2;
 `bytxt' replace `newvar'=(3*`origvar' 
                           + 2*(`origvar'[_n-1] + `origvar'[_n+1])
                           + 1*(`origvar'[_n-2] + `origvar'[_n+2]))/9
            if _n==3 | _n==_N-2;
 `bytxt' replace `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n==2 | _n==_N-1;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            


*A program to smooth series;
cap program drop smooth3;
program define smooth3;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(3*`origvar' 
                           + 2*(`origvar'[_n-1] + `origvar'[_n+1])
                           + 1*(`origvar'[_n-2] + `origvar'[_n+2]))/9
            if _n>2 | _n<_N-1;
 `bytxt' replace `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n==2 | _n==_N-1;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            

*A program to smooth series;
cap program drop smooth2;
program define smooth2;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n>1 & _n<_N;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            


*Start calculations;
 

baseval, w0(0.7 (0.005) 1.3) `parms' `simulparms';

matrix list basevals;

foreach policy in bonus tenure {;
 cap confirm `scratch'/models_table2_`policy'_fixedN.dta;
 if _rc==0 {;
 	 cap confirm `scratch'/models_table2_`policy'_fixedN.dta.gz;
 	 if _rc==0 {;
 	 	 !\rm `scratch'/models_table2_`policy'_fixedN.dta;
 	 	 !`zcatcmd' `scratch'/models_table2_`policy'_fixedN.dta.gz > `scratch'/models_table2_`policy'_fixedN.dta;
 	 };
 };
 else !`zcatcmd' `scratch'/models_table2_`policy'_fixedN.dta.gz > `scratch'/models_table2_`policy'_fixedN.dta;

  use if exper<=5 using `scratch'/models_table2_`policy'_fixedN.dta, clear;
  sort id year;
  by id year: gen matchhazard=hazard_[_n-1];
  keep if inlist(year, 1, 2, 6);
  *Work out equivalent variation in wage;
   assignw, bvals(basevals) tlist(1 2 6);
   gen mupt=round(normal(mu/`sig_t'), 0.01);
   replace equivw=100*(equivw-1);

   cap gen firedyet_=0;
   replace equivw=. if firedyet_==1;
   collapse (mean) equivw mu Surv_policy, by(mupt exper);
   sort exper mupt;
   rename equivw equivw_`policy';
   rename Surv_policy Surv_`policy';
   foreach v of varlist equivw_`policy' Surv_`policy' {;
   	 rename `v' `v'_orig;
   	 smooth3, newvar(`v') origvar(`v'_orig) byvar("exper (mupt)");
   };
  
   tempfile values_`policy';
   save `values_`policy'';
   
   gen mupt100=mupt*100;
   gen roundptile=round((mupt100)/5)*5;
   gen dist=abs(mupt100-roundptile);
   sort exper roundptile dist;
   by exper roundptile: gen every5=roundptile if _n==1;
   list exper mupt100 Surv_`policy' equivw_`policy' if every5<.;

   replace mupt100=. if Surv_`policy'<0.05;
   sort exper mupt100;
   
 /*
   if "`policy'"=="bonus" {;
     local legend `"legend(label(1 "At start of career") label(2 "After one year") label(3 "After five years") ring(0) cols(1) pos(11))"';
   };
   else local legend `"legend(off)"';
   line equivw_`policy' mupt100 if exper==0 || 
   line equivw_`policy' mupt100 if exper==1 || 
   line equivw_`policy' mupt100 if exper==5 ||,
        xlabel(0 (20) 100) xtitle("") ytitle("")
        title("`title'") `legend' yline(0, lcolor(gray)) ylabel(, nogrid)
        name(`policy', replace) nodraw;
 */
;

 if "`policy'"=="bonus" 
   line equivw_bonus mupt100 if exper==0 || 
   line equivw_bonus mupt100 if exper==1 || 
   line equivw_bonus mupt100 if exper==5 || ,
        xlabel(0 (20) 100) xtitle("") ytitle("")
        title("Annual bonuses") yline(0, lcolor(gray)) ylabel(, nogrid)
        legend(label(1 "At start of career") label(2 "After one year")
               label(3 "After five years") ring(0) cols(1) pos(11))
        name(bonus, replace) nodraw;
 if "`policy'"=="tenure" 
   line equivw_tenure mupt100 if exper==0 || 
   line equivw_tenure mupt100 if exper==1 || 
   line equivw_tenure mupt100 if exper==5 ||, 
        xlabel(0 (20) 100) xtitle("") ytitle("") legend(off)
        title("One-time tenure decision") yline(0, lcolor(gray)) ylabel(, nogrid)
        name(tenure, replace) nodraw;

 gen policy="`policy'";
 tempfile `policy';
 save ``policy'';
};

graph combine bonus tenure, xcommon ycommon 
      l1title("Equivalent variation in wage under base contract (%)")
      b1title("Percentile of true ability")
      saving(`thisdir'/`dofile'.gph, replace);

!\rm `scratch'/models_table2_tenure_fixedN.dta;
!\rm `scratch'/models_table2_bonus_fixedN.dta;

use `bonus';
append using `tenure';
save `thisdir'/`dofile'.dta, replace;

****Some statistics for the write-up;
 cap log close paperstats;
 log using "`thisdir'/`dofile'_paperstats.log", text replace name(paperstats);
 *********************************************************************;
 *An estimate of (for example) +5% means that w^{0}
 *would need to rise by 5% under contract C_{0}
 *to yield the same value as is obtained under the alternative contract. 
 *The figure shows that the bonus contract produces the equivalent of a 
 *#% salary increase for the average 95th percentile teacher at entry, 
 *and a #% increase after five years.
 *;
 *
 *The tenure contract achieves a much steeper slope among first year 
 *teachers, with a range of about ##% of baseline salaries between 10th 
 *and 90th percentile teachers, but like the bonus contract does little 
 *to alter the relative incentives governing the entry decision. ;
 *;
  list policy exper mupt100 equivw_bonus equivw_tenure if 
       abs(mupt100-90)<0.001 | abs(mupt100-95)<0.001 |
       abs(mupt100-10)<0.001 | abs(mupt100-5)<0.001 
       ;
 *********************************************************************;
 
 log close paperstats;
        
if `doasproject'==1 project, creates("`thisdir'/`dofile'.gph");
if `doasproject'==1 project, creates("`thisdir'/`dofile'.dta");
if `doasproject'==1 project, creates("`thisdir'/`dofile'_paperstats.log");
  
