*Figure 1. Objective probabilities of bonus receipt and tenure denial and average subjective expectations, 
*by true ability percentile & experience

version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes
}
else {
	local doasproject=0
	local pdir "~/projects/performancepay/project"
  local dofile "gph_info"
	local sig "Not run as part of project!"
}
local thisdir "`pdir'/figures"

#delimit;


set scheme lean1;
*tau is true ability.  Mu is prior.  Tau = mu + v. y = tau + e;

local sigma_t=0.15;
local sigma_e=sqrt(1.5)*`sigma_t';
local sigma_y=sqrt(`sigma_e'^2 + `sigma_t'^2);
local sigma_y2=sqrt(((`sigma_e'^2)/2) + `sigma_t'^2);
local h=0.4;
local bonusthreshold=.1779762655496597;
local tenurethreshold=-0.1670040361609002;

local sigma_mu=sqrt(`h')*`sigma_t';
local sigma_v=sqrt(`sigma_t'^2 - `sigma_mu'^2);
local s2_e=`sigma_e'^2;
local s2_t=`sigma_t'^2;
local sigma_v1=sqrt(1/((1/`s2_e') + (1/((1-`h')*`s2_t'))));
local sigma_v2=sqrt(1/((2/`s2_e') + (1/((1-`h')*`s2_t'))));
local sigma_v5=sqrt(1/((5/`s2_e') + (1/((1-`h')*`s2_t'))));
local sigma_v10=sqrt(1/((10/`s2_e') + (1/((1-`h')*`s2_t'))));
local sigma_t1=sqrt(`s2_t'-`sigma_v1'^2);
local sigma_t2=sqrt(`s2_t'-`sigma_v2'^2);
local sigma_t5=sqrt(`s2_t'-`sigma_v5'^2);
local sigma_t10=sqrt(`s2_t'-`sigma_v10'^2);

*Figure out probability of being denied tenure, based on year-1 info;
 local npts 99;
 set obs `npts';
 gen tauptile=_n/(`npts'+1);
 gen tau=`sigma_t'*invnormal(tauptile);
 expand `npts';
 sort tauptile;
 by tauptile: gen muptile=_n/(`npts'+1);
 gen mu=sqrt(1-`h')*`sigma_mu'*invnorm(muptile) + `h'*tau;
 expand `npts';
 sort tauptile muptile;
 by tauptile muptile: gen va1ptile=_n/(`npts'+1);
 gen va1=tau + `sigma_e'*invnorm(va1ptile);
 gen tauhat0=mu + (va1-mu)*((`sigma_v'/(`sigma_v'+`sigma_e'))^2);
 gen prfire_true=normal((`tenurethreshold'-tau)/(`sigma_e'/sqrt(2)));
 gen prfire_subj0=normal((`tenurethreshold' - mu)/sqrt(`sigma_v'^2 + (`s2_e'/2)));
 gen prfire_subj1=normal((2*`tenurethreshold' - va1 - tauhat0)/sqrt(`sigma_v1'^2 + `s2_e'));
 collapse (mean) prfire_* tau, by(tauptile);
 rename prfire_* prfireA_*;
 tempfile gridA;
 save `gridA';

drop _all;
set obs 999;
gen tauptile=_n/(_N+1);
gen tau=`sigma_t'*invnormal(tauptile);
gen prbonus_true=1-normal((`bonusthreshold'-tau)/(`sigma_e'/sqrt(2)));
gen prfire_true=normal((`tenurethreshold'-tau)/(`sigma_e'/sqrt(2)));


expand 999;
sort tauptile;
by tauptile: gen priorptile_t=_n/1000;
*Distribution of mu | t is N(R*t, (1-R)*sigma_mu^2), where R=(s_mu^2/s_tau^2)=h;
 gen mu=sqrt(1-`h')*`sigma_mu'*invnorm(priorptile_t) + `h'*tau;
 gen prbonus_subj0=1 - normal((`bonusthreshold' - mu)/sqrt(`sigma_v'^2 + (`s2_e'/2)));
 gen prfire_subj0=normal((`tenurethreshold' - mu)/sqrt(`sigma_v'^2 + (`s2_e'/2)));
 foreach t in 1 2 5 10 {;
  local h`t'=(`sigma_t`t'')^2/`s2_t';
  gen tauhat`t'=sqrt(1-`h`t'')*`sigma_t`t''*invnorm(priorptile_t) + `h`t''*tau;
  gen prbonus_subj`t'=1 - normal((`bonusthreshold' - tauhat`t')/sqrt(`sigma_v`t''^2 + (`s2_e'/2)));
 };
tempfile fullinfo;
save `fullinfo';
collapse (mean) prbonus_* prfire_* 
                tau, by(tauptile);
 merge 1:1 tauptile using `gridA';
gen ptile100=tauptile*100;

*Figure 1. Probability of bonus receipt and average subjective expectation of future receipt, 
*by true ability percentile & experience;
line prbonus_true prbonus_subj0 prbonus_subj1 prbonus_subj5 ptile100,
     xtitle("")
     ytitle("Probability of bonus receipt each year") ylabel(0 (0.2) 1)
     xlabel(0 (20) 100) 
     legend(off)
     name(one, replace) title("Bonus contract")
     ;

*gen prfire_subj1=.;
rename prfireA_subj1 prfire_subj1;
gen prfire_subj5=.;
line prfire_true prfire_subj0 prfire_subj1 prfire_subj5 ptile100,
     xtitle("")
     ytitle("Probability of tenure denial") ylabel(0 (0.2) 1)
     xlabel(0 (20) 100) 
     legend(label(1 "True probability") 
         label(2 "Avg. subj. pr. at entry") 
         label(3 "Avg. subj. pr. after 1 year")
         label(4 "Avg. subj. pr. after 5 years")
         ring(0) cols(1) pos(1))
     name(two, replace) title("Tenure contract")
     ;
graph combine one two, xcommon ycommon 
      b1title("Percentile of true ability")
      saving(`thisdir'/`dofile'.gph, replace);

save `thisdir'/`dofile'.dta, replace;

****Some statistics for the write-up;
 cap log close paperstats;
 log using "`thisdir'/`dofile'_paperstats.log", text replace name(paperstats);
 *********************************************************************;
 *Using the parameters from Table 1, teachers with \tau at the 90th percentile win ;
 *bonuses #% of the time, while those at the 50th percentile do so #% of the time.;
 *;
    list ptile100 prbonus_true prfire_true if abs(ptile100-90)<0.05 | abs(ptile100-50)<0.05;
 *********************************************************************;
 *Thus, even a teacher at the 90th percentile of the \mu distribution thinks she 
 *has only a #% chance of receiving a bonus in any given year of her career, while 
 *a teacher with 10th percentile \mu anticipates a #% chance. 
 *;
    use `fullinfo', clear;
    xtile muptile=mu, nquantiles(99) ;
    su muptile prbonus_subj0 prfire_subj0;
    _pctile mu, percentiles(10);
    local p10_mu=r(r1);
    su muptile mu prbonus_subj0 prfire_subj0 if abs(mu-`p10_mu')<0.00001;
    _pctile mu, percentiles(90);
    local p90_mu=r(r1);
    su muptile mu prbonus_subj0 prfire_subj0 if abs(mu-`p90_mu')<0.00001;
 *********************************************************************;
    
 *As teachers accumulate 
 *information, they quickly learn their places in the distribution. After one year, 
 *the teacher at the 90th percentile of the \hat{\tau}_{i1} distribution thinks her 
 *chance of receiving a bonus is #%, and this rises to #% after two years and #% 
 *after 5 years. 
 *;
    _pctile tauhat1, percentiles(90);
    su tauhat1 prbonus_subj1  if abs(tauhat1-r(r1))<0.00001;
    _pctile tauhat2, percentiles(90);
    su tauhat2 prbonus_subj2  if abs(tauhat2-r(r1))<0.00001;
    _pctile tauhat5, percentiles(90);
    su tauhat5 prbonus_subj5  if abs(tauhat5-r(r1))<0.00001;
    
    _pctile tauhat1, percentiles(10);
    su tauhat1 prbonus_subj1  if abs(tauhat1-r(r1))<0.00001;
    _pctile tauhat2, percentiles(10);
    su tauhat2 prbonus_subj2  if abs(tauhat2-r(r1))<0.00001;
    _pctile tauhat5, percentiles(10);
    su tauhat5 prbonus_subj5  if abs(tauhat5-r(r1))<0.00001;

 *********************************************************************;
    
 *Again, this is particularly true early in the career: At entry, the average 90th 
 *percentile teacher's subjective expectation of her own ability puts her at only 
 *the #th percentile, while the average 10th percentile teacher guesses herself to 
 *be at the #th percentile.
 *;
    su mu if abs(tauptile-0.9)<0.0005;
    di "percentile in true tau distribution is: " normal(r(mean)/`sigma_t');
    su mu if abs(tauptile-0.1)<0.0005;
    di "percentile in true tau distribution is: " normal(r(mean)/`sigma_t');
 
 *********************************************************************;
  
 *At the point of entry into teaching there is very little differentiation except 
 *at the extreme tails of the distribution: The average 90th percentile teacher 
 *anticipates a ##% of earning a bonus in any given year while the average 10th 
 *percentile teacher perceives her chance at ##%. But perceived incentives become 
 *much better targeted as teachers gain experience -- by the 5th year of their 
 *careers, the 90th percentile teachers perceive their chances at ##%, on average, 
 *while the 10th percentile teachers see theirs as ##%. Thus, while incentive 
 *effects of a bonus system are weak at the recruitment stage, later attrition 
 *decisions may be more sensitive to these incentives
 *;
  use `dofile', clear;
  list prbonus_true prbonus_subj0 prbonus_subj1 prbonus_subj5 ptile100 if ptile100==5*floor(ptile100/5);
 
 *********************************************************************;
  
 
  log close paperstats;
 
 

if `doasproject'==1 project, creates("`thisdir'/`dofile'.gph");
if `doasproject'==1 project, creates("`thisdir'/`dofile'.dta");
if `doasproject'==1 project, creates("`thisdir'/`dofile'_paperstats.log");


