version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

  project, uses("`pdir'/scratch/models_table2_tenure_fixedN.dta.gz")
  project, uses("`pdir'/scratch/models_table2_bonus_fixedN.dta.gz")
}
else {
	local doasproject=0
	local pdir "~/projects/performancepay/project"
  local dofile "gph_newentrants"
	local sig "Not run as part of project!"
}
local thisdir "`pdir'/figures"
local scratch "`pdir'/scratch"
#delimit;


clear;
set more off;
set scheme lean1;

local sig_t=0.15;
if c(os)=="MacOSX" local zcatcmd "gzcat";
else local zcatcmd "zcat";

cap program drop smooth4;
program define smooth4;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(4*`origvar' 
                       + 3*(`origvar'[_n-1] + `origvar'[_n+1])
                       + 2*(`origvar'[_n-2] + `origvar'[_n+2])
                       + 1*(`origvar'[_n-3] + `origvar'[_n+3]))/16
            if _n>3 & _n<_N-2;
 `bytxt' replace `newvar'=(3*`origvar' 
                           + 2*(`origvar'[_n-1] + `origvar'[_n+1])
                           + 1*(`origvar'[_n-2] + `origvar'[_n+2]))/9
            if _n==3 | _n==_N-2;
 `bytxt' replace `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n==2 | _n==_N-1;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            


*A program to smooth series;
cap program drop smooth3;
program define smooth3;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(3*`origvar' 
                           + 2*(`origvar'[_n-1] + `origvar'[_n+1])
                           + 1*(`origvar'[_n-2] + `origvar'[_n+2]))/9
            if _n>2 | _n<_N-1;
 `bytxt' replace `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n==2 | _n==_N-1;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            

*A program to smooth series;
cap program drop smooth2;
program define smooth2;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n>1 & _n<_N;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            


foreach policy in bonus tenure {;
 cap confirm `scratch'/models_table2_`policy'_fixedN.dta;
 if _rc==0 {;
 	 cap confirm `scratch'/models_table2_`policy'_fixedN.dta.gz;
 	 if _rc==0 {;
 	 	 !\rm `scratch'/models_table2_`policy'_fixedN.dta;
 	 	 !`zcatcmd' `scratch'/models_table2_`policy'_fixedN.dta.gz > `scratch'/models_table2_`policy'_fixedN.dta;
 	 };
 };
 else !`zcatcmd' `scratch'/models_table2_`policy'_fixedN.dta.gz > `scratch'/models_table2_`policy'_fixedN.dta;

	use if year==1 using `scratch'/models_table2_`policy'_fixedN.dta, clear;
  gen mupt=round(normal(mu/`sig_t'), 0.01);
  collapse (mean) entryweight mu, by(mupt);
  sort mupt;
  smooth2, newvar(recruit_`policy') origvar(entryweight);
  replace recruit_`policy'=100*(recruit_`policy'-1);
  keep mupt mu recruit_`policy';
  tempfile recruit`policy';
  save `recruit`policy'';
};
use `recruitbonus';
merge 1:1 mupt using `recruittenure', gen(mrg);
 
 gen mupt100=mupt*100;
 line recruit_bonus recruit_tenure mupt100,
      xlabel(0 (10) 100) ylabel(-10 (10) 20) yline(0, lcolor(gray))  ylabel(, nogrid)
      xtitle("Percentile of true ability")
      ytitle("Change in number of new hires (%)")
      legend(label(1 "Bonus") label(2 "Tenure") ring(0) pos(5) cols(1))
      saving(`thisdir'/`dofile'.gph, replace);

save `thisdir'/`dofile'.dta, replace;
      
!\rm `scratch'/models_table2_tenure_fixedN.dta;
!\rm `scratch'/models_table2_bonus_fixedN.dta;

if `doasproject'==1 project, creates("`thisdir'/`dofile'.gph");
if `doasproject'==1 project, creates("`thisdir'/`dofile'.dta");
      
