version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

  project, uses("`pdir'/scratch/models_table2_tenure_fixedN.dta.gz")
  project, uses("`pdir'/scratch/models_table2_bonus_fixedN.dta.gz")
}
else {
	local doasproject=0
	local pdir "~/projects/performancepay/project"
  local dofile "gph_totalnumber"
	local sig "Not run as part of project!"
}
local thisdir "`pdir'/figures"
local scratch "`pdir'/scratch"
#delimit;

clear;
set more off;
set scheme lean1;

local sig_t=0.15;
if c(os)=="MacOSX" local zcatcmd "gzcat";
else local zcatcmd "zcat";

cap program drop smooth4;
program define smooth4;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(4*`origvar' 
                       + 3*(`origvar'[_n-1] + `origvar'[_n+1])
                       + 2*(`origvar'[_n-2] + `origvar'[_n+2])
                       + 1*(`origvar'[_n-3] + `origvar'[_n+3]))/16
            if _n>3 & _n<_N-2;
 `bytxt' replace `newvar'=(3*`origvar' 
                           + 2*(`origvar'[_n-1] + `origvar'[_n+1])
                           + 1*(`origvar'[_n-2] + `origvar'[_n+2]))/9
            if _n==3 | _n==_N-2;
 `bytxt' replace `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n==2 | _n==_N-1;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            


*A program to smooth series;
cap program drop smooth3;
program define smooth3;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(3*`origvar' 
                           + 2*(`origvar'[_n-1] + `origvar'[_n+1])
                           + 1*(`origvar'[_n-2] + `origvar'[_n+2]))/9
            if _n>2 | _n<_N-1;
 `bytxt' replace `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n==2 | _n==_N-1;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            

*A program to smooth series;
cap program drop smooth2;
program define smooth2;
 syntax, newvar(string) origvar(string) [byvar(string)];
 if "`byvar'"=="" local bytxt="";
 else local bytxt="bysort `byvar':";
 `bytxt' gen `newvar'=(2*`origvar' 
                           + 1*(`origvar'[_n-1] + `origvar'[_n+1]))/4
            if _n>1 & _n<_N;
 `bytxt' replace `newvar'=`origvar' if _n==1 | _n==_N;
end;            

  
foreach policy in bonus tenure {;
 cap confirm `scratch'/models_table2_`policy'_fixedN.dta;
 if _rc==0 {;
 	 cap confirm `scratch'/models_table2_`policy'_fixedN.dta.gz;
 	 if _rc==0 {;
 	 	 !\rm `scratch'/models_table2_`policy'_fixedN.dta;
 	 	 !`zcatcmd' `scratch'/models_table2_`policy'_fixedN.dta.gz > `scratch'/models_table2_`policy'_fixedN.dta;
 	 };
 };
 else !`zcatcmd' `scratch'/models_table2_`policy'_fixedN.dta.gz > `scratch'/models_table2_`policy'_fixedN.dta;

	use `scratch'/models_table2_`policy'_fixedN, clear;
  sort id year;
  cap confirm var firedyet_;
  if _rc==0 gen weight_policy_alt=Surv*(firedyet_==0);
  else gen weight_policy_alt=Surv;
  gen mupt=round(normal(mu/`sig_t'), 0.01);
  collapse (mean) Surv weight_policy weight_policy_alt mu, by(mupt);
  rename Surv base;
  gen policy=100*((weight_policy/base)-1);
  gen policy_alt=100*((weight_policy_alt/base)-1);
  smooth4, newvar(`policy') origvar(policy);
  smooth4, newvar(`policy'_alt) origvar(policy_alt);
  keep mupt mu `policy' `policy'_alt;
  sort mupt;
  tempfile neteffect`policy';
  save `neteffect`policy'';
};

use `neteffectbonus';
merge 1:1 mupt using `neteffecttenure', gen(mrg1);

gen mupt100=mupt*100;
*line bonus tenure tenure_alt mupt100,
     xtitle("Percentile of true ability") xlabel(0 (10) 100)
     ytitle("Change in number of teachers (%)") yline(0, lcolor(gray)) ylabel(, nogrid)
     legend(label(1  "Bonus") label(2 "Tenure") label(3 "Tenure (no behavioral response)") ring(0) pos(5) cols(1))
     saving(`thisdir'/`dofile'.gph, replace);
;
line bonus tenure mupt100,
     xtitle("Percentile of true ability") xlabel(0 (10) 100)
     ytitle("Change in number of teachers (%)") yline(0, lcolor(gray)) ylabel(, nogrid)
     legend(label(1  "Bonus") label(2 "Tenure") ring(0) pos(3) cols(1))
     saving(`thisdir'/`dofile'.gph, replace);
;

save `thisdir'/`dofile'.dta, replace;
      
!\rm `scratch'/models_table2_tenure_fixedN.dta;
!\rm `scratch'/models_table2_bonus_fixedN.dta;

****Some statistics for the write-up;
 cap log close paperstats;
 log using "`thisdir'/`dofile'_paperstats.log", text replace name(paperstats);
 *********************************************************************;
 *Not surprisingly, the bonus contract has relatively small effects, 
 *reducing the number of low ability teachers by about #% and increasing 
 *the number of high ability teachers by a bit more than this. The tenure 
 *policy is much more effective, increasing the number of classes taught 
 *by top-quartile teachers by about 20% and reducing those taught by bottom 
 *decile teachers by #%. ;
 *;
  list mupt100 bonus bonus_alt tenure tenure_alt
       if abs(mupt100 - 10*floor(mupt100/10))<0.1;
  gen quartile=1+1*(mupt100>=25)+1*(mupt100>=50)+1*(mupt100>=75);
  table quartile, contents(mean bonus mean tenure mean tenure_alt);
  gen decile=floor(mupt100/10);
  replace decile=10 if mupt100==100;
  table decile, contents(mean bonus mean tenure mean tenure_alt);
 *********************************************************************;
 log close paperstats;
 
if `doasproject'==1 project, creates("`thisdir'/`dofile'.gph");
if `doasproject'==1 project, creates("`thisdir'/`dofile'.dta");
if `doasproject'==1 project, creates("`thisdir'/`dofile'_paperstats.log");
      
