version 12.1

cap project, doinfo
if _rc==0 {
  local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes
  local doasproject=1

  *project, uses("`pdir'/scratch/models_table2_bonus_fixedN.dta.gz")
  project, uses(`pdir'/varycontracts/vary_bonussize.dta)
  project, uses(`pdir'/varycontracts/vary_bonusshare.dta)
  project, uses(`pdir'/varycontracts/vary_frfired.dta)
  project, uses(`pdir'/varycontracts/vary_frfiredavgva.dta)
  project, uses(`pdir'/varycontracts/vary_frfiredoptimal.dta)
  project, uses(`pdir'/varycontracts/vary_frtenured.dta)
  project, uses(`pdir'/varycontracts/vary_budget.dta)
  project, uses(`pdir'/varycontracts/vary_rescale.dta)
  *project, uses(vary_rescale.dta)
}
else {
	local pdir "~/projects/performancepay/project"
  local dofile "varygraphs"
	local sig "Not run as part of project!"
  local doasproject=0
}
local thisdir "`pdir'/figures"
local contracts "`pdir'/varycontracts"
local scratch "`pdir'/scratch"
#delimit;


clear;
set more off;
set scheme lean1;

local sizeeffect=(100*0.004);

cap program drop addzero;
program define addzero;
  syntax varlist;
  sort `varlist' policy;
  egen grouping=group(`varlist');
  su grouping, meanonly;
  local ng=r(max);
  sort grouping policy;
  qui count if policy<.;
  assert policy~=0 & policy~=.;
  local nobs=r(N)+`ng';
  set obs `nobs';
  sort grouping policy;
  by grouping: replace grouping=_n if grouping==.;
  replace policy=0 if policy==.;
  sort grouping policy;
  by grouping: replace policyproductivity_mean=baseproductivity_mean[2] if policy==0;
  by grouping: replace baseproductivity_mean=baseproductivity_mean[2] if policy==0;
  by grouping: replace basenteach=basenteach[2] if policy==0;
  by grouping: replace policynteach=basenteach[2] if policy==0;
  by grouping: replace policytype=policytype[2] if policy==0;
  foreach v of varlist `varlist' {;
  	by grouping: replace `v'=`v'[2] if policy==0;
  };
  drop grouping;
end;

tempfile bonussize bonusshare frfired frfiredavgva frfiredoptimal frtenured budget;

use `contracts'/vary_bonussize;
gen policytype="bonussize";
rename _bonussize policy;
addzero _parmset;
save `bonussize';

use `contracts'/vary_bonusshare;
gen policytype="bonusshare";
rename _frbonus policy;
addzero _parmset;
save `bonusshare';

use `contracts'/vary_frfired;
gen policytype="frfired";
rename _frfired policy;
addzero _parmset;
save `frfired';

use `contracts'/vary_frfiredavgva;
gen policytype="frfiredavgva";
rename _frfired policy;
addzero _parmset;
save `frfiredavgva';

use `contracts'/vary_frfiredoptimal;
gen policytype="frfiredoptimal";
rename _frfired policy;
addzero _parmset;
save `frfiredoptimal';

use `contracts'/vary_frtenured;
gen policytype="frtenured";
gen policy=1-_frtenured;
drop _frtenured;
addzero _parmset _tenuredate;
save `frtenured';

use `contracts'/vary_budget;
gen policytype="budget";
gen policy=1-_frtenured;
drop _frtenured;
save `budget';

use `frfired';
append using `frfiredavgva';
append using `frfiredoptimal';
merge m:1 policytype policy _num using `contracts'/vary_rescale.dta, assert(1 3);
assert policy==0 if _merge==1;
drop _merge;
replace frfired_cumul=0 if policy==0;

append using `frtenured';
append using `bonussize';
append using `bonusshare';
append using `budget';
replace _tenuredate=0 if _tenuredate==.;
isid policytype _parmset _tenuredate policy;
gen dnteach=ln(policynteach/basenteach);
gen toteffect=policyproductivity_mean - baseproductivity_mean + `sizeeffect'*dnteach;

save `thisdir'/`dofile', replace;

forvalues p=0/2 {;
  gen toteffect_bonussize_`p'=toteffect if policytype=="bonussize" & _parmset==`p';
  gen toteffect_perfpay_`p'=toteffect if policytype=="perfpay" & _parmset==`p';
  gen toteffect_bonusshare_`p'=toteffect if policytype=="bonusshare" & _parmset==`p';
  gen toteffect_frfired_`p'=toteffect if policytype=="frfired" & _parmset==`p';
  gen toteffect_frfiredavgva_`p'=toteffect if policytype=="frfiredavgva" & _parmset==`p';
  gen toteffect_frfiredoptimal_`p'=toteffect if policytype=="frfiredoptimal" & _parmset==`p';
  gen toteffect_frtenured1_`p'=toteffect if policytype=="frtenured" & _tenuredate==1 & _parmset==`p';
  gen toteffect_frtenured2_`p'=toteffect if policytype=="frtenured" & _tenuredate==2 & _parmset==`p';
  gen toteffect_frtenured3_`p'=toteffect if policytype=="frtenured" & _tenuredate==3 & _parmset==`p';
  gen toteffect_frtenured4_`p'=toteffect if policytype=="frtenured" & _tenuredate==4 & _parmset==`p';
  gen toteffect_frtenured5_`p'=toteffect if policytype=="frtenured" & _tenuredate==5 & _parmset==`p';
  gen toteffect_altbudget_`p'=toteffect if policytype=="budget" &  _parmset==`p';
};


line toteffect_bonussize_0 toteffect_bonussize_1 toteffect_bonussize_2 policy ,
     xline(0.2, lcolor(gs12))
     xtitle("Bonus as share of base compensation") ytitle("Effect on average output")
     legend(off) title("Varying bonus size")
     name(bonussize, replace) nodraw;
line toteffect_bonusshare_0 toteffect_bonusshare_1 toteffect_bonusshare_2 policy if policy<=0.6,
     xline(0.25, lcolor(gs12))
     xtitle("Share awarded bonuses") ytitle("Effect on average output")
     legend(label(1 "Base parameters") label(2 "Pessimistic") label(3 "Optimistic") order(3 1 2) cols(1) ring(0) pos(1))
     title("Varying no. of bonuses awarded")
     name(bonusshare, replace) nodraw;
graph combine bonussize bonusshare, ycommon
     saving(`thisdir'/`dofile'_bonuses.gph, replace);

preserve;
replace toteffect_frtenured1_1=. if toteffect_frtenured1_1<-0.03;
replace toteffect_frtenured2_1=. if toteffect_frtenured2_1<-0.03;
replace toteffect_frtenured3_1=. if toteffect_frtenured3_1<-0.03;
replace toteffect_frtenured4_1=. if toteffect_frtenured4_1<-0.03;

line toteffect_frtenured1_0 toteffect_frtenured2_0 toteffect_frtenured3_0 toteffect_frtenured4_0 policy if policy<=0.6 ||
scatter toteffect_frtenured2_0 policy if abs(policy-0.2)<0.001, msymbol(Th) mcolor(black) ||,
     xtitle("Fraction denied tenure") ytitle("Effect on avg. output") ylabel(0 (0.01) 0.04, nogrid) yline(0, lcolor(gray)) 
      title("Base parameters") legend(off)
     name(tenure0, replace) nodraw;
line toteffect_frtenured1_1 toteffect_frtenured2_1 toteffect_frtenured3_1 toteffect_frtenured4_1 policy if policy<=0.6 ||
scatter toteffect_frtenured2_1 policy if abs(policy-0.2)<0.001, msymbol(Th) mcolor(black) ||,
     xtitle("Fraction denied tenure") ytitle("Effect on avg. output") ylabel(-0.03 (0.01) 0.01, nogrid) yline(0, lcolor(gray))
      title("Pessimistic parameters") legend(off)
     name(tenure1, replace) nodraw;
line toteffect_frtenured1_2 toteffect_frtenured2_2 toteffect_frtenured3_2 toteffect_frtenured4_2 policy if policy<=0.6 ||
scatter toteffect_frtenured2_2 policy if abs(policy-0.2)<0.001, msymbol(Th) mcolor(black) ||,
     xtitle("Fraction denied tenure") ytitle("Effect on avg. output") ylabel(0 (0.01) 0.04, nogrid) yline(0, lcolor(gray))
      title("Optimistic parameters") 
     legend(off)
     name(tenure2, replace) nodraw;
line toteffect_frtenured1_2 toteffect_frtenured2_2 toteffect_frtenured3_2 toteffect_frtenured4_2 policy if policytype=="bonusshare" &  policy<=0.6,
      legend(subtitle("Tenure decision after:") label(1 "1 year") label(2 "2 years") label(3 "3 years") label(4 "4 years") ring(0) pos(0) cols(1))
     xlabel(none) ylabel(none) xtitle("") ytitle("") plotregion(fcolor(bg) style(none)) yscale(off) xscale(off) name(legendplot, replace) nodraw;
     
graph combine tenure0 legendplot tenure1  tenure2, xcommon saving(`thisdir'/`dofile'_tenure.gph, replace);

replace toteffect_altbudget_1=. if toteffect_altbudget_1<-0.03;
line toteffect_frtenured2_0 toteffect_altbudget_0 policy if policy<=0.6 ||
scatter toteffect_frtenured2_0 policy if abs(policy-0.2)<0.001, msymbol(Th) mcolor(black) ||,
     xtitle("Fraction denied tenure") ytitle("Effect on avg. output") ylabel(0 (0.01) 0.04, nogrid) yline(0, lcolor(gray)) 
      title("Base parameters") legend(off)
     name(budget0, replace) nodraw;
line toteffect_frtenured2_1 toteffect_altbudget_1 policy if policy<=0.6 ||
scatter toteffect_frtenured2_1 policy if abs(policy-0.2)<0.001, msymbol(Th) mcolor(black) ||,
     xtitle("Fraction denied tenure") ytitle("Effect on avg. output") ylabel(-0.02 (0.01) 0.02, nogrid) yline(0, lcolor(gray)) 
      title("Pessimistic parameters") legend(off)
     name(budget1, replace) nodraw;
line toteffect_frtenured2_2 toteffect_altbudget_2 policy if policy<=0.6 ||
scatter toteffect_frtenured2_2 policy if abs(policy-0.2)<0.001, msymbol(Th) mcolor(black) ||,
     xtitle("Fraction denied tenure") ytitle("Effect on avg. output") ylabel(0 (0.01) 0.06, nogrid) yline(0, lcolor(gray)) 
      title("Optimistic parameters") legend(off)
     name(budget2, replace) nodraw;
line toteffect_frtenured2_0 toteffect_altbudget_0 policy if policytype=="bonusshare" &  policy<=0.6,
      legend(label(1 "Baseline budget") label(2 "5% budget increase") ring(0) pos(0) cols(1))
     xlabel(none) ylabel(none) xtitle("") ytitle("") plotregion(fcolor(bg) style(none)) yscale(off) xscale(off) 
     name(legendplot, replace) nodraw;
graph combine budget0 legendplot budget1 budget2, xcommon saving(`thisdir'/`dofile'_budget.gph, replace);

restore;
replace toteffect_frtenured2_1=. if toteffect_frtenured2_1<-0.05;
replace toteffect_frfiredavgva_1=. if toteffect_frfiredavgva_1<-0.05;
replace toteffect_frfired_1=. if toteffect_frfired_1<-0.05;
replace toteffect_frfiredoptimal_1=. if toteffect_frfiredoptimal_1<-0.05;

line toteffect_frtenured2_0 policy if policy<=0.8 || 
line toteffect_frfiredavgva_0 toteffect_frfired_0 toteffect_frfiredoptimal_0 frfired_cumul if frfired_cumul<=0.8 ||,
     xtitle("Fraction fired by year 30") ytitle("Effect on avg. output") ylabel(, nogrid) yline(0, lcolor(gray))
     title("Base parameters") legend(off)
     name(fire0, replace) nodraw;
line toteffect_frtenured2_1 policy if policy<=0.8 || 
line toteffect_frfiredavgva_1 toteffect_frfired_1 toteffect_frfiredoptimal_1 frfired_cumul if frfired_cumul<=0.8,
     xtitle("Fraction fired by year 30") ytitle("Effect on avg. output") ylabel(-0.04 (0.02) 0.02, nogrid) yline(0, lcolor(gray))
     title("Pessimistic parameters") legend(off)
     name(fire1, replace) nodraw;
line toteffect_frtenured2_2 policy if policy<=0.8 || 
line toteffect_frfiredavgva_2 toteffect_frfired_2 toteffect_frfiredoptimal_2 frfired_cumul if frfired_cumul<=0.8,
     xtitle("Fraction fired by year 30") ytitle("Effect on avg. output") ylabel(, nogrid) yline(0, lcolor(gray))
     title("Optimistic parameters") legend(off)
     name(fire2, replace) nodraw;
line toteffect_frtenured2_0 policy if policy<=0.8  & policytype=="bonusshare" || 
line toteffect_frfiredavgva_0 toteffect_frfired_0 toteffect_frfiredoptimal_0 frfired_cumul if frfired_cumul<=0.8 & policytype=="bonusshare",
      legend(subtitle("Firing decision based on:") label(1 "Performance over first 2 years (tenure)") label(2 "Average performance to date") 
             label(3 "Posterior mean ability") label(4 `""Optimal" decision rule"') ring(0) pos(0) cols(1))
     xlabel(none) ylabel(none) xtitle("") ytitle("") plotregion(fcolor(bg) style(none)) yscale(off) xscale(off) name(legendplot, replace) nodraw;

graph combine fire0 legendplot fire1 fire2 , xcommon saving(`thisdir'/`dofile'_fire.gph, replace);


if `doasproject'==1 {;
	project, creates("`thisdir'/`dofile'.dta");
	project, creates("`thisdir'/`dofile'_fire.gph");
	project, creates("`thisdir'/`dofile'_tenure.gph");
	project, creates("`thisdir'/`dofile'_budget.gph");
	project, creates("`thisdir'/`dofile'_bonuses.gph");
};
