*Program to simulate the effect of a bonus paid based on a 2-year moving average of measured performance;

#delimit;
 
cap program drop learningmodel_bonus;
program define learningmodel_bonus, rclass;
syntax using/, 
         /*Teacher career parameters*/
           basehazard(string) maxt(real) expreturn(real)  fixedcost_base(real) fixedcost_policy(real) 
         /*Teacher effectiveness parameters*/
           sigma_mu(real) expeffect(string) h(real) corrtruth(real)
         /*Performance measures*/
           rsignal(real)
         /*Performance pay policy*/
           frbonus(real) bonussize(real) expadjust(real) policybase(real)
         /*Preference parameters*/
           crra(real) crra_type(string) discount(real) elast_exit(string) elast_entry(string) maxwage(real)
         /*Simulation parameters*/
           gridpts(integer) simulobs(integer)
         /*Base contract parameters*/
           bonusthreshold(real) sdeffect_base(real) vareffect_base(real) avgeffect_base(real) meanwage_base(real) 
           nteach_base(real) elast_valwage(real) initialvalue(real) eta_exit(name)
        [*];
  *This program has one parameter more than in the outer program:
  *  bonusbase:  The base pay under the bonus policy as a fraction of the base under the base contract;


 clear;
 clear results;
 *clear matrix;
 *Generate a new local variable, since this has been renamed;
  local bonusbase=`policybase';
  
  *Some calculations;
    local var_mu=`sigma_mu'^2;
    local var_e=`var_mu'*(1-`rsignal')/`rsignal';
    local sigma_e=sqrt(`var_e');
    local var_sig=`var_mu'+`var_e';
    local sigma_sig=sqrt(`var_sig');
    local priorvar0=`var_mu'*(1-`h');
    local var_prior0=`var_mu'*`h';
  *Extract the c and eta parameters;
   matrix list `eta_exit';
   forvalues t=2/`maxt' {;
  	 local eta`t'=el(`eta_exit', `t', 2);
  	 local c`t'=el(`eta_exit', `t', 3);
   };

  **Work out the variance of the prior at each year -- will use this to make grid points;
     *At period t, have t-1 signals, on top of initial prior tau with mu|tau ~ N(tau, (1-h)s2_mu);
     *So posterior variance is [((1-h)s2_mu)^-1 + (s2_e/T)^-1]^-1;
    local priorvar_1=(1-`h')*`var_mu';
    forvalues t=2/`maxt' {;
    	 local s=`t'-1;
    	 local priorvar_`t'=1/( (1/`priorvar_`s'') + (1/`var_e'));
    };
    forvalues t=1/`maxt' {;
      local varprior_`t'=`var_mu'-`priorvar_`t'';
    	 local priorsd_`t'=sqrt(`priorvar_`t'');
    	 local sdprior_`t'=sqrt(`varprior_`t'');
      *di "t=`t', sdprior=`sdprior_`t'', priorsd=`priorsd_`t''";
    };
  

  **Make a grid of prior - previous signal values, evenly spaced in the distribution;
    tempfile priorpts;
    sub_makeinitialgrid, gridpts(`gridpts') var_prior0(`var_prior0') maxt(`maxt') priorvar_1(`priorvar_1') 
                      var_e(`var_e') var_mu(`var_mu') ctype("bonus") expeffect(`"`expeffect'"');
    save `priorpts';

  **Now need to turn to the actual learning model / value function evaluation.;
    ***Start with period T;
      *Value function entering period T, assuming a prior signal;
      local t=`maxt';
      local s=`maxt'-1;
      use g_prior g_lastsig prior`maxt' va`s' exppart`s' exppart`maxt' using `priorpts';
      gen basewage=(1+`expreturn')^`s';
      expand `gridpts';
      sort g_prior g_lastsig;
      by g_prior g_lastsig: gen g_sig`t'=_n;
      gen sig`maxt'=invnorm(g_sig`t'/(`gridpts'+1))*sqrt(`priorvar_`maxt'' + `var_e');
      gen va`maxt'=sig`maxt'+prior`maxt';
      gen avgva=(va`s'+va`maxt')/2;
      if `expadjust'==0 {;
      	replace avgva=avgva+(exppart`s'+exppart`maxt')/2;
      };
      gen byte bonus=(avgva>`bonusthreshold') if avgva<.;
      gen wage_policy=basewage*`policybase'*(1+`bonussize'*bonus);
      gen exper=`s';
      gen basehaz=`basehazard';
      su basehaz, meanonly;
      local baseh=r(mean);
      sub_valfn, crra(`crra') etanext(0) next(`maxt') basehazard(`baseh') cnext(0)
                 maxwage(`maxwage') discount(`discount') crra_type(`crra_type') lastperiod
                 collapseby(g_prior prior`maxt' g_lastsig) extracollapse(bonus);
      gen exper=`s';
      gen hazard_`s'=(`basehazard')*(`c`maxt''/valfn_`maxt')^`eta`maxt''; *Hazard of voluntary exit between T-1 and T;
      replace hazard_`s'=1 if hazard_`s'>1 & hazard_`s'<.;
      rename bonus bonus`maxt';

      keep g_prior g_lastsig valfn_`maxt' hazard_`s' bonus`maxt';
      sort g_prior g_lastsig;
      rename g_prior g_prior`t';
      rename g_lastsig g_sig`s';
      compress;
      tempfile value_`maxt';
      save `value_`maxt'';
    ***Now period t;
      local penultimate=`maxt'-1;
      local first=1;
      forvalues t=`penultimate' (-1) `first' {;    
      *Loop over t;	
      	local next=`t'+1;  
      	local s=`t'-1; 
      	di "STARTING t=`t'";
        use g_prior g_lastsig prior`t' va`s' exppart`s' exppart`t' using `priorpts';
        gen basewage=(1+`expreturn')^(`t'-1);
        expand `gridpts';
        sort g_prior g_lastsig ;
        rename g_prior g_prior`t';
        rename g_lastsig g_sig`s';
        by g_prior`t' g_sig`s' : gen g_sig`t'=_n;
        gen sig`t'=invnorm(g_sig`t'/(`gridpts'+1))*sqrt(`priorvar_`t'' + `var_e');
        gen va`t'=prior`t'+sig`t';
        if `s'>0 {;
          gen avgva=(va`s'+va`t')/2;
          if `expadjust'==0 {;
         	 replace avgva=avgva+(exppart`s'+exppart`t')/2;
          };
          gen byte bonus=(avgva>`bonusthreshold') if avgva<.;
        };
        else gen byte bonus=0;
        gen wage_policy=basewage*`policybase'*(1+`bonussize'*bonus);
        gen exper=`s';
        gen basehaz=`basehazard';
        su basehaz, meanonly;
        local baseh=r(mean);
        *Update priors;
          gen postmean=prior`t' + sig`t'*(`priorvar_`t''/(`priorvar_`t''+`var_e'));
        *Need to round prior so we can merge to the next period;
          gen g_prior`next'=round((`gridpts'+1)*normal(postmean/`sdprior_`next''));
          replace g_prior`next'=1 if g_prior`next'<1;
          replace g_prior`next'=`gridpts' if g_prior`next'>`gridpts';
          *gen g_sig`t'=round((`gridpts'+1)*normal(sig`t'/sqrt(`priorvar_`next''+`var_e')));
          *replace g_sig`t'=1 if g_sig`t'<1;
          *replace g_sig`t'=`gridpts' if g_sig`t'>`gridpts';
        *Merge;
          merge m:1 g_prior`next' g_sig`t' using `value_`next'', assert(2 3) keep(3)
                keepusing(g_prior`next' g_sig`t' valfn_`next' hazard_`t');
          drop _merge;
        *Calculate certainty-equivalent of next periods utiity, taking account of possibility of exit
        *to outside option next period.;
          sub_valfn, crra(`crra') etanext(`eta`next'') next(`next') basehazard(`baseh') 
                     cnext(`c`next'') maxwage(`maxwage') discount(`discount') 
                     crra_type(`crra_type') extracollapse(bonus) 
                     collapseby(g_prior`t' g_sig`s');
          cap drop wage_policy;
          if `s'>0 {;
          	gen exper=`s';
          	gen hazard_`s'=(`basehazard')*(`c`t''/valfn_`t')^`eta`t'';
          };
          else gen hazard_`s'=0;
          replace hazard_`s'=1 if hazard_`s'>1 & hazard_`s'<.;
          *drop ra_thisperiod;
        *rename g_prior`t' g_prior;
        *rename g_sig`s' g_lastsig;
        rename bonus bonus`t';
        sort g_prior`t' g_sig`s';
        compress;
        tempfile value_`t';
        save `value_`t'';
      *End of loop over t;
      };
  **Simulate data to get actual joint distributions;
    use id pvtinfo mu muB va* g_prior* g_sig* prior* sig* using `using';
   *Calculate bonuses;
    gen byte gotbonus1=0;
    forvalues t=2/`maxt' {;
    	local s=`t'-1;
   		if `expadjust'==0 {;
       	gen byte gotbonus`t'=(((vaunadj`t'+vaunadj`s')/2)>`bonusthreshold');
      };
      else {;
      	gen byte gotbonus`t'=(((va`t'+va`s')/2)>`bonusthreshold');
      };
    };
   *Merge to the value function data to get hazards;
     gen exper=.;
     forvalues t=1/`maxt' {;
     	 local s=`t'-1;
     	 replace exper=`s';
     	 merge m:1 g_prior`t' g_sig`s' using `value_`t'', assert(2 3) keep(3);
     	 rename bonus`t' altbonus`t';
     	 if `t'==1 {;
     	 	 gen Surv1=1;
     	 	 gen Surv_policy1=1;
     		 gen entryweight=((valfn_1-`fixedcost_policy')/(`initialvalue'-`fixedcost_base'))^((`elast_entry')/`elast_valwage');
         replace entryweight=0 if entryweight<0;
     	 };
     	 else {;
     	 	 local s=`t'-1;
     	 	 gen Surv`t'=Surv`s'*(1-(`basehazard'));
     	 	 gen Surv_policy`t'=Surv_policy`s'*(1-hazard_`s');
         replace Surv_policy`t'=0 if Surv_policy`t'<0;
     	 	 *drop hazard_`s';
       };
     	 drop _merge ;
     };
     cap drop sig*;
     cap drop vaunadj*;
     drop exper;
     
*Compute the information we need without reshaping -- # of teachers & total wages;
 local nteach_base=0;
 local totsal_base=0;
 local nteach_policy=0;
 local totsal_policy=0;
 gen weight_policy=.;
 gen exper=.;
 gen wage_policy=.;
 forvalues t=1/`maxt' {;
 	 replace exper=`t'-1;
 	 su Surv`t', meanonly;
 	 local nteach_base=`nteach_base'+r(mean)/`maxt';
 	 local totsal_base=`totsal_base' + r(mean)*((1+`expreturn')^(`t'-1))/`maxt';
 	 replace weight_policy=entryweight*Surv_policy`t';
 	 su weight_policy, meanonly;
 	 local nteach_policy=`nteach_policy'+r(mean)/`maxt';
 	 local nt=r(mean);
   replace wage_policy=((1+`expreturn')^exper)*`bonusbase'*(1+`bonussize'*gotbonus`t');
   su wage_policy [aw=weight_policy], meanonly;
 	 local totsal_policy=`totsal_policy' + `nt'*r(mean)/`maxt';
 };
 drop weight_policy wage_policy exper;

 return scalar nteach_base=`nteach_base';
 return scalar nteach_policy=`nteach_policy';
 return scalar totsal_base=`totsal_base';
 return scalar totsal_policy=`totsal_policy';
/*
   *Reshape to make a teacher-by-year data set;
     reshape long prior va getbonus  Surv Surv_policy valfn_ hazard_ altbonus avgva, i(id) j(year);
     drop if year>`maxt';
     drop if year<1;
     gen byte exper=year-1;
     gen expeffect=`expeffect';
     gen basewage=(1+`expreturn')^exper;
     rename getbonus bonus;
     gen wage_policy=basewage*`bonusbase'*(1+`bonussize'*bonus);
     gen fired_=0;
     
  *Compute output to return -- we only need # of teachers from this;
     *Number of teachers under base policy;
       su Surv, meanonly;
       return scalar nteach_base=r(mean);
     *Number of teachers under alternative policy;
       gen weight_policy=entryweight*Surv_policy;
       su weight_policy, meanonly;
       return scalar nteach_policy=r(mean); 
 */  
  **A few extra parameters;
   *return scalar bonusthreshold=`bonusthreshold';
   *return matrix eta_exit=`eta_exit';
   *return scalar eta_entry=`eta_entry';
end;

   