*base_fixedN.do

version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

  project, original("`pdir'/subroutines/project_includesubroutines.do")
  project, original("`pdir'/learningmodels/learningmodel_tenure.do")
  project, original("`pdir'/learningmodels/learningmodel_bonus.do")
}
else {
    local doasproject=0
	local pdir "~/projects/performancepay/project"
	local dofile "models_table2"
	local sig "Not run as part of project!"
	
}
run `pdir'/subroutines/project_includesubroutines.do
run `pdir'/learningmodels/learningmodel_tenure.do
run `pdir'/learningmodels/learningmodel_bonus.do
local thisdir "`pdir'/mainmodels"

#delimit;

*Internal subroutines;
 cap program drop savefile;
 program savefile;
   args filename;
   cap ! \rm `filename'.dta.gz;
   save `"`filename'"', replace;
   ! gzip `filename'.dta;
 end;
 
*Set parameters that will be used for all calls by this program;
 local filebase `"`pdir'/scratch/`dofile'"';
 local tableout `"`thisdir'/`dofile'_table.txt"';
 local samp `"`pdir'/scratch/`dofile'_samp.dta"';
 local parms `"elast_entry(1) elast_exit(1) fireeffect("(-0.01*min(exper,10))") h(0.1) crra(0) crra_type("none")"';
 local parms1 `"elast_entry(0.5) elast_exit(0.5) fireeffect("-0.15") h(0.05) crra(3) crra_type("cashinhand") "';
 local parms2 `"elast_entry(1.5) elast_exit(1.5) fireeffect("(-0.01*min(exper,5))") h(0.25) crra(0) crra_type("none")"';

 local simulparms `"gridpts(149) simulobs(200000) store searchwage tol(0.00005)"';


*Prepare the sample that will be used throughout;
 if `doasproject'==1 project, uses(`pdir'/scratch/drawsamp.dta);
 sub_makesamp, basesamp(`pdir'/scratch/drawsamp) `parms' `simulparms';
 save `samp', replace;
 tempfile samp1 samp2;
 sub_makesamp, basesamp(`pdir'/scratch/drawsamp) `parms1' `simulparms';
 save `samp1', replace;
 sub_makesamp, basesamp(`pdir'/scratch/drawsamp) `parms2' `simulparms';
 save `samp2', replace;

runmodel using `samp', ctype("tenure") name("tenureA") startwage(1.125543756695891) criteria(numteach) `parms' `simulparms';
matrix results_tenureA=e(b)'; 
savefile `filebase'_tenure_fixedN;

runmodel using `samp', ctype("bonus") name("bonusA") startwage(0.9651623548907431) criteria(numteach) `parms' `simulparms';
matrix results_bonusA=e(b)'; 
savefile `filebase'_bonus_fixedN;

runmodel using `samp', ctype("tenure") name("tenureB") startwage(1.103817939758300781) criteria(totcost) `parms' `simulparms';
matrix results_tenureB=e(b)'; 
savefile `filebase'_tenure_fixedcost;

runmodel using `samp', ctype("bonus") name("bonusB") startwage(0.9652251601219177246) criteria(totcost) `parms' `simulparms';
matrix results_bonusB=e(b)'; 
savefile `filebase'_bonus_fixedcost;


*Redo for alternative parameters - pessimistic;
runmodel using `samp1', ctype("tenure") name("tenureA1") startwage(1.578026652336120605) criteria(numteach) `parms1' `simulparms';
matrix results_tenureA1=e(b)'; 
runmodel using `samp1', ctype("bonus") name("bonusA1") startwage(0.9727188348770141602) criteria(numteach) `parms1' `simulparms';
matrix results_bonusA1=e(b)'; 
runmodel using `samp1', ctype("tenure") name("tenureB1") startwage(1.271248459815979004) criteria(totcost) `parms1' `simulparms';
matrix results_tenureB1=e(b)'; 
runmodel using `samp1', ctype("bonus") name("bonusB1") startwage(0.9710157513618469238) criteria(totcost) `parms1' `simulparms';
matrix results_bonusB1=e(b)'; 

*Redo for alternative parameters - optimistic;
runmodel using `samp2', ctype("tenure") name("tenureA2") startwage(1.084640622138977051) criteria(numteach) `parms2' `simulparms';
matrix results_tenureA2=e(b)'; 
runmodel using `samp2', ctype("bonus") name("bonusA2") startwage(0.9647580981254577637) criteria(numteach) `parms2' `simulparms';
matrix results_bonusA2=e(b)'; 
runmodel using `samp2', ctype("tenure") name("tenureB2") startwage(1.074136734008789062) criteria(totcost) `parms2' `simulparms';
matrix results_tenureB2=e(b)'; 
runmodel using `samp2', ctype("bonus") name("bonusB2") startwage(0.9647198915481567383) criteria(totcost) `parms2' `simulparms';
matrix results_bonusB2=e(b)'; 

esttab bonusA tenureA bonusB tenureB 
       bonusA1 tenureA1 bonusB1 tenureB1
       bonusA2 tenureA2 bonusB2 tenureB2
       using `tableout', replace not plain;
matrix allresults=results_bonusA, results_tenureA, results_bonusB, results_tenureB,
                  results_bonusA1, results_tenureA1, results_bonusB1, results_tenureB1,
                  results_bonusA2, results_tenureA2, results_bonusB2, results_tenureB2;
matrix results2data=allresults';
drop _all;
set obs 4;
svmat results2data, names(eqcol);
gen str model="bonusA" in 1;
replace model="tenureA" in 2;
replace model="bonusB" in 3;
replace model="tenureB" in 4;

replace model="bonusA" in 5;
replace model="tenureA" in 6;
replace model="bonusB" in 7;
replace model="tenureB" in 8;
replace model="bonusA" in 9;
replace model="tenureA" in 10;
replace model="bonusB" in 11;
replace model="tenureB" in 12;

gen parms=1*(_n>4) + 1*(_n>8);

save `thisdir'/`dofile'.dta, replace;

if `doasproject'==1 {;
	project, creates(`"`samp'"');
  project, creates(`thisdir'/`dofile'.dta);
  project, creates("`filebase'_tenure_fixedN.dta.gz");
  project, creates("`filebase'_bonus_fixedN.dta.gz");
  project, creates("`filebase'_tenure_fixedcost.dta.gz");
  project, creates("`filebase'_bonus_fixedcost.dta.gz");
  project, creates("`tableout'");
};
