*Program to explore the impact of fixed entry costs;

version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

  project, original("`pdir'/subroutines/project_includesubroutines.do")
  project, original("`pdir'/learningmodels/learningmodel_tenure.do")
  project, original("`pdir'/learningmodels/learningmodel_bonus.do")
  project, uses("`pdir'/scratch/drawsamp.dta")
}
else {
    local doasproject=0
	local pdir "~/projects/performancepay/project"
	local dofile "models_table4"
	local sig "Not run as part of project!"
	
}
run `pdir'/subroutines/project_includesubroutines.do
run `pdir'/learningmodels/learningmodel_tenure.do
run `pdir'/learningmodels/learningmodel_bonus.do
local thisdir "`pdir'/mainmodels"

#delimit;

*Set parameters that will be used for all calls by this program;
 local filebase `"`pdir'/scratch/`dofile'"'; 
 local tableout `"`thisdir'/`dofile'_table.txt"';
 local parms1 `"elast_entry(1) elast_exit(1) fireeffect("(-0.01*min(exper,10))") h(0.1) crra(0) crra_type("none")"';
 local parms2 `"elast_entry(0.5) elast_exit(0.5) fireeffect("-0.15") h(0.05) crra(3) crra_type("cashinhand") "';
 local simulparms `"gridpts(149) simulobs(200000) criteria(totcost) store searchwage tol(0.00005)"';

 local costs00 `"fixedcost_base(0) fixedcost_policy(0)"';
 local costs10 `"fixedcost_base(1) fixedcost_policy(0)"';
 local costs11 `"fixedcost_base(1) fixedcost_policy(1)"';
 
 

*Prepare the sample that will be used throughout;
 tempfile samp;
 if `doasproject'==1 project, uses(`pdir'/scratch/drawsamp.dta);
 sub_makesamp, basesamp(`pdir'/scratch/drawsamp) `parms1' `simulparms';
 save `samp', replace;

local startw1_bonusA  "0.9652066230773925781";
local startw1_tenureA "1.10381007194519043  ";
local startw1_bonusB  "0.965217292308807373 ";
local startw1_tenureB "1.103352069854736328 ";
local startw1_nofc    "0.952865302562713623 ";
local startw1_bonusC  "0.9197171330451965332";
local startw1_tenureC "1.052848100662231445 ";

*Start with no baseline fixed cost;
 runmodel using `samp', ctype("bonus") name("bonusA_1") startwage(`startw1_bonusA') `parms1' `simulparms';
 matrix results=e(b)'; 
 matrix allresults=nullmat(allresults), results; 
 local modlist "`modlist' bonusA_1";
 runmodel using `samp', ctype("tenure") name("tenureA_1") startwage(`startw1_tenureA') `parms1' `simulparms';
 matrix results=e(b)'; 
 matrix allresults=nullmat(allresults), results; 
 local modlist "`modlist' tenureA_1";

*Now baseline & policy fixed costs;
 runmodel using `samp', ctype("bonus") name("bonusB_1") startwage(`startw1_bonusB') `costs11' `parms1' `simulparms';
 matrix results=e(b)'; 
 matrix allresults=nullmat(allresults), results; 
 local modlist "`modlist' bonusB_1";
 runmodel using `samp', ctype("tenure") name("tenureB_1") startwage(`startw1_tenureB') `costs11' `parms1' `simulparms';
 matrix results=e(b)'; 
 matrix allresults=nullmat(allresults), results; 
 local modlist "`modlist' tenureB_1";

*And baseline fixed costs, eliminated in policy;
 runmodel using `samp', ctype("tenure") frtenured(0.9999) name("nofc_1") startwage(`startw1_nofc') `costs10' `parms1' `simulparms';
 matrix results=e(b)'; 
 matrix allresults=nullmat(allresults), results; 
 local modlist "`modlist' nofc_1";
 runmodel using `samp', ctype("bonus") name("bonusC_1") startwage(`startw1_bonusC') `costs10' `parms1' `simulparms';
 matrix results=e(b)'; 
 matrix allresults=nullmat(allresults), results; 
 local modlist "`modlist' bonusC_1";
 runmodel using `samp', ctype("tenure") name("tenureC_1") startwage(`startw1_tenureC') `costs10' `parms1' `simulparms';
 matrix results=e(b)'; 
 matrix allresults=nullmat(allresults), results; 
 local modlist "`modlist' tenureC_1";


   esttab `modlist' using `tableout', replace not plain;
   matrix results2data=allresults';
   drop _all;
   set obs 7;
   svmat results2data, names(eqcol);
gen str model="bonusA" in 1;
replace model="tenureA" in 2;
replace model="bonusB" in 3;
replace model="tenureB" in 4;
replace model="nofc" in 5;
replace model="bonusC" in 6;
replace model="tenureC" in 7;
gen parmset=0 in 1/7;
order model parmset;
   save `thisdir'/`dofile'.dta, replace;



if `doasproject'==1 project, creates("`thisdir'/`dofile'.dta");
if `doasproject'==1 project, creates("`tableout'");

