/*
--------------------------------------------------------------------------------

This is the master do-file of the "ppay" project, which corresponds to the 
May 2014 version of "Teacher Quality Policy When Supply Matters," by Jesse
Rothstein.

See "README.txt" for instructions on how to run this project

The principal investigator for this project is:

	Jesse Rothstein    rothstein@berkeley.edu
	
I am grateful to Robert Picard, picard@netbox.com, for the "project.ado"
program used to implement the project.

--------------------------------------------------------------------------------
*/


	version 12.1

* Common settings

	set more off
	set varabbrev off	// for long projects, it's best not to abbreviate
	set linesize 132	// use 7pt font for printing
	
  which project
  *Should be:
    */accounts/projects/jr_ra/ado/plus/p/project.ado
    *! version 1.3.1  22dec2013  picard@netbox.com
  *To check for updates, type:
  * adoupdate project

  * This directory includes a local copy of -project- in a zip archive. This
  * is done to ensure replicability in case of future changes in -project- or
  * if -project- becomes unavailable, or if you are unable to install it from
  * the SSC archives. Make it part of the project
 	project, relies_on("project.zip")
 	project, relies_on("estout.zip")

  * Make the read me file part of the project
 	project, relies_on("README.txt")
	
	
  

* Preparatory

   project, do("subroutines/drawsamp.do")

*Run base models
   project, do("mainmodels/models_table2.do") 

   project, do("mainmodels/models_table3.do")

   project, do("mainmodels/models_table4.do")

*Make initial graphs
   project, do(figures/gph_info.do)
   project, do(figures/gph_equivalentvariation.do)
   project, do(figures/gph_newentrants.do)
   project, do(figures/gph_careerlength.do)
   project, do(figures/gph_recruitretain.do)
   project, do(figures/gph_totalnumber.do)

*Run models that vary the bonus share, bonus size, fraction tenured, etc.   
   project, do(varycontracts/vary_bonusshare.do)
   project, do(varycontracts/vary_bonussize.do)
   project, do(varycontracts/vary_frtenured.do)

*Run alternative firing models
   project, do(varycontracts/vary_frfiredavgva.do)
   project, do(varycontracts/vary_frfired.do)
   project, do(varycontracts/optimalfirethresholds.do)
   project, do(varycontracts/vary_frfiredoptimal.do)

*Run models that vary the budget
   project, do(varycontracts/vary_budget.do)
   project, do(varycontracts/vary_budget2.do)

*Assemble the alternative contracts results and report  
   project, do(varycontracts/vary_rescale.do)
   project, do(figures/varygraphs.do)
   project, do(figures/optimalpolicies.do)

*Appendix
   project, do(appendix/appendix_exithazard.do)
   project, do(appendix/appendix_altfiringruns.do)
   project, do(appendix/appendix_altfiringfig.do)
   