#delimit;

/*Needs:
 * sub_findthresholds
 * sub_makebetas
 * sub_baselineparms
 * learningmodel_`ctype'
 *   sub_makeinitialgrid
 * sub_summarize
 * sub_search
*/
 
cap program drop runmodel;
program define runmodel;
 syntax using, [quietly name(string) *];
 
 `quietly' runmodel_sub_runone `using', `options';
 return list;
 matrix list r(hazards);
 matrix list r(eta_exit);

 sub_makebetas `name' runmodel;
 ereturn list;
 if `"`name'"'~=`""' estimates store `name';

end;

cap program drop runmodel_sub_runone;
program define runmodel_sub_runone, rclass;
syntax using, [/*Teacher career parameters*/
           basehazard(string) maxt(real 30) expreturn(real 0.015) fixedcost_base(real 0) fixedcost_policy(real 0)
         /*Teacher effectiveness parameters*/
           sigma_mu(real 0.15) expeffect(string) h(real 0.25) corrtruth(real 1)
         /*Performance measures*/
           rsignal(real 0.4)
         /*Contract type*/
           ctype(string)
         /*Bonus policy*/
           frbonus(real 0.25) bonussize(real 0.2) expadjust(real 1) 
         /*Continuous performance pay policy*/
           ppayslope(real 0.15) ppaymin(real 0.5001) ppaymax(real 9999)
         /*Firing policy*/
           frfired(real 0.1) fireeffect(string) firerule(string) firemat(name)
         /*Tenure policy*/
           frtenured(real 0.8) tenuredate(real 2) 
         /*Manipulation*/
           k(real 0.2) sigmau(real 0.1162) transfer(integer 0)
         /*Preference parameters*/
           crra(real 3) crra_type(string) discount(real 0.03) elast_exit(string) elast_entry(string) maxwage(real 2)
         /*Simulation parameters*/
           gridpts(integer 49) simulobs(integer 50000) startwage(real -1) tol(real 0.0001) searchwage 
           criteria(string) criterionratio(real 1)
         * ];
  *Set defaults for non-numeric parameters;         
    if `"`expeffect'"'==`""' local expeffect="-0.07*(exper==0)-0.04*(exper==1)-0.02*(exper==2)";
    if `"`ctype'"'==`""' local ctype="bonus";
    if `"`crra_type'"'==`""' local crra_type="none";
    if `"`crra_type'"'==`"none"' local crra=0;
    if (`fixedcost_base'>0 | `fixedcost_policy'>0) & `"`crra_type'"'~="none" {;
    	di "Programs cant accommodate a fixed cost of entry with nonlinear vN-M utility";
    	err;
    };
    if `"`basehazard'"'==`""' local basehazard="0.08";
    if `"`elast_entry'"'==`""' local elast_entry="3";
    if `"`elast_exit'"'==`""' local elast_exit="3";
    if `"`fireeffect'"'==`""' local fireeffect="-0.1";
    if `"`criteria'"'==`""' local criteria="numteach";
    if `"`firerule'"'==`""' local firerule="posterior";
    
    
 /*
  *Documentation:
  Category  Parameter   default   Interpretation
  Teacher careers
            basehazard  0.08      Function of experience that evaluates to the fraction of teachers who exit voluntarily each year under base contract.
            maxt        30        Maximum length of teacher career
            expreturn   0.015     Salary return to experience in base contract
            fixedcost_base 0      Fixed cost (in dollars) that must be paid in first period for certification, under base contract.
            fixedcost_policy 0    Same thing, under alternative contract
  Teacher effectiveness
            sigma_mu    0.15      Standard deviation of effectiveness among teachers hired under base contract.
            expeffect   <text>    Effect of experience on teacher impacts
            h           0.25      SD of prior mean, on entry to teaching, as fraction of sigma_mu.
            corrtruth   1         Correlation between mu and true effectiveness.
  Performance measure
            rsignal     0.25       Reliability of the annual effectiveness signal (net of experience effects)
  Contracttype
            ctype       bonus     "bonus" or "fire" or "ppay" or "tenure" -- how will the contract be tweaked?
  Bonus
            frbonus     0.25      Fraction of teachers who would receive bonus (in current pool)
            bonussize   0.2       Size of bonus, as multiple of base salary
  Performance pay
            ppayslope   0.15      % increase in pay for each SD (of current distn) by which posterior exceeds 0.
  Firing policy 
            frfired     0.1       Fraction of current teachers who would be fired
            fireeffect  -0.1      Effect of being fired on the value function, expressed as function of experience
            firerule    posterior Variable used for firing decisions: "posterior" vs. "avgva".
  Tenure policy 
            frtenured   0.1       Fraction of current teachers who would be fired
            tenuredate  2         Year after which tenure decisions are made.
            fireeffect  -0.1      (Same as in firing policy) Effect of being fired on the value function
  Common to all policies
            policybase  1         The base pay under the bonus/firing policy as a fraction of the base under the base contract
  Preference parameters
            crra        3         Relative risk aversion coefficient
            crra_type   orig      orig=original model -- risk averse over PDV of lifetime income.  
                                  cashinhand=cash-in-hand with risk aversion
                                  none=not risk averse
            discount    0.03      Real discount rate
            elast_exit  3         Function of "exper" that evaluates to the semi-elasticity of the exit hazard 
                                  at each period with respect to a permanent pay increase.
            elast_entry 3         Function of "pvtinfo" that evaluates to the elasticity 
                                  of entry with respect to a permanent pay increase
                                  *Note:  If careers were infinite, elasticity of LS wrt to base pay would be the sum of these.;
                                  *But with T=30, elasticity is only around (elast_entry + 0.77*elast_exit).;
            maxwage     2         Maximum outside wage (as multiple of the base wage).
  Manipulation (only relevant if `ctype' allows it)
            k           0.2       Cost (as % of baseline starting salary) for raising measured effectiveness by sigmau. 
                                  Cost of other manipulations is proportional to square of manipulation.
            sigmau      0.1162    Amount by which measured effectiveness can be raised for cost `k'.  Calibrated
                                  based on SD(tau1 | tau2), when (tau1, tau2) ~ N(0, sigma_mu, sigma_mu, corr=0.4).
            transfer    0         If 1, manipulation reduces true effectiveness
  Simulation parameters
            gridpts     49        Number of points in the grid used for the value function evaluation
            simulobs    100000    Number of teachers in simulations
            startwage   -1        Initial guess at market-clearing wage (-1=no guess)
            tol         0.0001    How close do we need to get with mkt clearing wage.
            searchwage  off       If on, search over policy base wage to satisfy criterion.
            criterion   numteach  Quantity that policy wage is adjusted to hold constant.  Options are
                                  numteach, totsal, totcost.
            criterionratio  1     Total value of criterion to reach, as multiple of baseline.                                  
 */
          
 *This outer program sets up the problem and either runs the learning model once (if searchwage is off)
 *or searches over "policybase" to find a value such that the (number of teachers / total salary bill)
 *is the same as under the base contract;

  drop _all;
  clear;
  clear results;

  
  local baseopts `"ctype(`"`ctype'"')"';
  local baseopts `"`baseopts' basehazard(`"`basehazard'"') maxt(`maxt') expreturn(`expreturn') fixedcost_base(`fixedcost_base') fixedcost_policy(`fixedcost_policy')"';
  local baseopts `"`baseopts' sigma_mu(`sigma_mu') expeffect(`"`expeffect'"') h(`h') corrtruth(`corrtruth')"';
  local baseopts `"`baseopts' rsignal(`rsignal')"';
  local baseopts `"`baseopts' frbonus(`frbonus') bonussize(`bonussize') expadjust(`expadjust')"';
  local baseopts `"`baseopts' ppayslope(`ppayslope') ppaymin(`ppaymin') ppaymax(`ppaymax')"';
  local baseopts `"`baseopts' frfired(`frfired') fireeffect(`"`fireeffect'"') firerule(`"`firerule'"') firemat(`firemat')"';
  local baseopts `"`baseopts' frtenured(`frtenured') tenuredate(`tenuredate')"';
  local baseopts `"`baseopts' crra(`crra') crra_type(`"`crra_type'"') discount(`discount') elast_exit(`"`elast_exit'"') elast_entry(`"`elast_entry'"') maxwage(`maxwage')"';
  local baseopts `"`baseopts' k(`k') sigmau(`sigmau') transfer(`transfer')"';
  local baseopts `"`baseopts' gridpts(`gridpts') simulobs(`simulobs') startwage(`startwage') tol(`tol') `searchwage' criteria(`"`criteria'"') criterionratio(`criterionratio')"';
*  local baseopts `"`baseopts' sample("`sample'")"';
  *List options;
   local nopts : word count `baseopts';
   di "***Options***";
   di `"`using'"';
   forvalues i=1/`nopts' {;
   	  local w : word `i' of `baseopts';
   	  di `"`w'"';
   	};
   di "***End of options***";
  *Some calculations;
    local var_mu=`sigma_mu'^2;
    local var_e=`var_mu'*(1-`rsignal')/`rsignal';
    local sigma_e=sqrt(`var_e');
    local var_sig=`var_mu'+`var_e';
    local sigma_sig=sqrt(`var_sig');
    local priorvar0=`var_mu'*(1-`h');
    local var_prior0=`var_mu'*`h';
    di "***Calculated parameters***";
    foreach v in var_mu var_e sigma_e var_sig sigma_sig priorvar0 var_prior0 {;
    	di "`v' = ``v''";
    	return scalar `v'=``v'';
    	local baseparms `"`baseparms' `v'(``v'')"';
    };
    	
 *Check that the sample is the right size;
  use g_pvtinfo `using';
 	su g_pvtinfo, meanonly;
 	if r(N)~=`simulobs' | r(max)~=`gridpts' {;
 		di "Sample is not conformable";
 		error 459;
  };
 *First, figure out the baseline parameters, using the base contract.;
   qui  sub_baselineparms, `baseopts';
   foreach item in sdeffect_base vareffect_base avgeffect_base meanwage_base nteach_base initialvalue elast_valwage avgelast {;
   	 local `item'=r(`item');
   	 local baseparms `"`baseparms' `item'(``item'')"';
   	 di "`item' = ``item''";
   	 return scalar `item'=``item'';
   };
   matrix etaexit=r(eta_exit);
   matrix valfired=r(val_fired);
*   matrix etaentry=r(eta_entry);
   return matrix eta_exit=etaexit, copy;
*   return matrix etaentry=etaentry, copy;
   sub_findthresholds, `baseopts' `baseparms';
   local thresholdparms `"`r(parmstring)'"';
   local baseparms `"`baseparms' `thresholdparms' eta_exit(etaexit) val_fired(valfired)"';
   matrix list etaexit;
   matrix list valfired;

 *Either estimate once, or call search to loop until optimized;
  if `"`searchwage'"'==`""' & `startwage'>0 {;
  	*Estimate the model once;
  	    qui learningmodel_`ctype' `using', `baseopts' `baseparms'
                                   policybase(`startwage');
        local basewage_policy=`startwage';     
        if `"`criteria'"'==`"numteach"' local criterion=(r(nteach_policy)/r(nteach_base))-`criterionratio';
        else if `"`criteria'"'==`"totsal"' local criterion=(r(totsal_policy)/r(totsal_base))-`criterionratio';
        else if `"`criteria'"'==`"totcost"' local criterion=((r(totsal_policy) + 2*r(totsal_base)*(r(nteach_policy)/r(nteach_base)))/(3*r(totsal_base)))-`criterionratio';
        if abs(`criterion') < `tol' local converged=1;
        else local converged=0;
        local nruns=1;
  };
  else if `"`searchwage'"'==`""' {;
  	di "****ERROR:  MUST SPECIFY WAGE IF DONT SPECIFY SEARCH***";
  	error 184;
  };
  else {;
  	*Figure out a good starting point;
  	  if `startwage'<=0 {;
  	  	gen feffect=`fireeffect';
  	  	su feffect [aw=Surv], meanonly;
    	  if `"`ctype'"'==`"bonus"' local x0=1/(1+`bonussize'*`frbonus');
      	else if `"`ctype'"'==`"fire"' | `"`ctype'"'==`"firemanip"' 
      	     local x0=1/(1+r(mean)*`frfired');
   	    else if `"`ctype'"'==`"tenure"' local x0=1/(1+r(mean)*(1-`frtenured'));
   	    else if `"`ctype'"'==`"ppay"' | `"`ctype'"'==`"ppaymanip"' local x0=1;
   	    local startwage `x0';
      };
  	sub_search `using', `baseopts' `baseparms' startwage(`startwage') criterion(`"`criteria'"');
  	local basewage_policy=r(basewage_policy);
  	local converged=r(converged);
  	local criterion=r(criterion);
  	local nruns=r(nruns);
  };
  local totsal_policy=r(totsal_policy);
  local nteach_policy=r(nteach_policy);
  local totsal_base=r(totsal_base);
  local nteach_base=r(nteach_base);

*Reshape to make a teacher-by-year data set;
 *drop g_avgsig*;
 if inlist(`"`ctype'"', `"fire"', `"tenure"') {;
 	 keep id mu muB entryweight va* prfired_* fired_* firedyet_* Surv* valfn_* hazard_*;
 	 cap drop vaunadj*;
 	 reshape long va prfired_ fired_ firedyet_ Surv Surv_policy valfn_ hazard_, i(id) j(year);
 	 keep id mu muB entryweight va prfired_ fired_ firedyet_ Surv Surv_policy valfn_ hazard_ year;
 };
 if `"`ctype'"'==`"bonus"' {;
 	 keep id mu muB entryweight va* gotbonus* Surv* valfn_* hazard_* altbonus*;
   reshape long va gotbonus  Surv Surv_policy valfn_ hazard_ altbonus, i(id) j(year);
 	 keep id mu muB entryweight va gotbonus Surv Surv_policy valfn_ hazard_ altbonus year;
 };
 if `"`ctype'"'==`"ppay"' {;
 	 keep id mu muB entryweight avgva* va* Surv* valfn_* hazard_* dposterior*;
   reshape long avgva va Surv Surv_policy valfn_ hazard_ dposterior, i(id) j(year);
   keep id mu muB entryweight avgva va Surv Surv_policy valfn_ hazard_ dposterior year;
 };
 drop if year>`maxt';
 drop if year<1;
 gen byte exper=year-1;
 gen expeffect=`expeffect';
 gen basewage=(1+`expreturn')^exper;
 gen weight_policy=entryweight*Surv_policy;
 gen wage_policy=basewage*`basewage_policy';
 if `"`ctype'"'==`"bonus"' {;
 	 rename gotbonus bonus;
 	 rename altbonus prbonus;
   replace wage_policy=wage_policy*(1+`bonussize'*bonus);
   gen byte fired_=0;
  };
 if `"`ctype'"'==`"ppay"' {;
  *Recompute wages -- the ones we have here come from the merge to the value function and can
  *be inaccurate in the tails;
   sort id year;
   *by id (year): gen avgva=sum(va)/year;
   *by id (year): gen dposterior=(avgva[_n-1])*`var_mu'/(`var_mu' + (`var_e'/(year-1)));
   *replace dposterior=0 if year==1;
   replace wage_policy=wage_policy*(1 + `ppayslope'*(dposterior/`sigma_mu'));
   drop avgva;  
   gen byte fired_=0;
 };

  return scalar basewage_policy=`basewage_policy';
  return scalar converged=`converged';
  return scalar nruns=`nruns';
  return scalar criterion=`criterion';
  return scalar totsal_policy=`totsal_policy';
  return scalar nteach_policy=`nteach_policy';
  return scalar totsal_base=`totsal_base';
  return scalar nteach_base=`nteach_base';
  qui sub_summarize;
  return add;
   *return scalar bonusthreshold=`bonusthreshold';
   *return matrix eta_exit=`eta_exit';
   *return scalar eta_entry=`eta_entry';
end;

