#delimit;

 cap program drop sub_baselineparms;
 program define sub_baselineparms, rclass;
   syntax, /*Teacher career parameters*/
             basehazard(string) maxt(real) expreturn(real) 
           /*Teacher effectiveness parameters*/
            sigma_mu(real) expeffect(string) h(real)
           /*Performance measures*/
             rsignal(real)
           /*Firing policy*/
             fireeffect(string)
           /*Preference parameters*/
             crra(real) crra_type(string) discount(real) elast_exit(string) elast_entry(string) maxwage(real)
           /*Simulation parameters*/
             gridpts(integer) 
            [ * ];
  
  **Uncover parameters of the baseline contract / outside wage offer distribution.;
  *Assume F_t(w) = 1 - lambda*(c/w)^eta if w<Hc, and F_t(Hc)=1, where:
  * c is the value function under the base contract
  * H is the maximum wage
  * and lambda is the hazard rate;
  *Output is a data set (kept in memory);
  *Some calculations;
    local var_mu=`sigma_mu'^2;
    local var_e=`var_mu'*(1-`rsignal')/`rsignal';
    local sigma_e=sqrt(`var_e');
    local var_sig=`var_mu'+`var_e';
    local sigma_sig=sqrt(`var_sig');
    local priorvar0=`var_mu'*(1-`h');
    local var_prior0=`var_mu'*`h';

  *Need to decide how many values to evaluate for firing;
   drop _all;
   set obs `maxt';
   gen t=_n;
   gen exper=_n; *Experience at the _end_ of the period in which worker is fired;
   gen fireeffect=`fireeffect';
list;
   tempname firecost;
   mkmat fireeffect, matrix(`firecost');
   forvalues t=1/`maxt' {;
   	 local firemult_`t'=1+el(`firecost', `t', 1); *Effect of being fired after `t' on future value;
   };

   *Run through the value function evaluation 3 times;
   *At base wage;
   *At 1.01*base wage -- for use in computing elasticities;
   *At a fraction of the original wage -- continuation value for those who are fired;
    drop _all;
    set obs 1;
    *Calculate value function at base wage;
     gen wage_policy=(1+`expreturn')^(`maxt'-1);
     gen exper=`maxt'-1;
     gen basehaz`maxt'=`basehazard';
     su basehaz`maxt', meanonly;
     local baseh=r(mean);
     sub_valfn, crra(`crra') etanext(0) next(`maxt') basehazard(`baseh') cnext(0)
                maxwage(`maxwage') discount(`discount') crra_type("`crra_type'")
                lastperiod;
     rename valfn_`maxt' baseval_`maxt';
    *Calculate value function at 1.01*base wage, for use in computing elasticity of value wrt wage;
     replace wage_policy=1.01*(1+`expreturn')^(`maxt'-1);
     sub_valfn, crra(`crra') etanext(0) next(`maxt') basehazard(`baseh') cnext(0)
                maxwage(`maxwage') discount(`discount') crra_type("`crra_type'")
                lastperiod;
     rename valfn_`maxt' highval_`maxt';
    *Calculate value function at a fraction of the base wage, for use in computing elasticity of value wrt wage;
     forvalues s=1/`maxt' {;
       replace wage_policy=`firemult_`s''*(1+`expreturn')^(`maxt'-1);
       local mw_`s'=`firemult_`s''*`maxwage';
       sub_valfn, crra(`crra') etanext(0) next(`maxt') basehazard(`baseh') cnext(0)
                  maxwage(`mw_`s'') discount(`discount') crra_type("`crra_type'")
                  lastperiod;
       rename valfn_`maxt' lowval_`s'_`maxt';
     };
     gen fireval_`maxt'=lowval_`maxt'_`maxt';
    *Compute elasticity of value with respect to the wage, and thus the eta that gives the appropriate exit elasticity;
     gen elast_`maxt'=((highval_`maxt'-baseval_`maxt')/baseval_`maxt')/0.01;
     gen eta_`maxt'=(`elast_exit')/elast_`maxt';
     forvalues n=2/`maxt' {;
   	   local t=`maxt'-`n'+1;
   	   local next=`t'+1;
   	   replace exper=`t'-1;
       gen basehaz`t'=`basehazard';
       su basehaz`t', meanonly;
       local baseh=r(mean);
   	   *Value at base wage;
   	   replace wage_policy=(1+`expreturn')^(`t'-1);
   	   gen valfn_`next'=baseval_`next';
   	   local eta=eta_`next';
   	   local c=baseval_`next';
       sub_valfn, crra(`crra') etanext(`eta') next(`next') basehazard(`baseh') cnext(`c')
                  maxwage(`maxwage') discount(`discount') crra_type("`crra_type'");
       rename valfn_`t' baseval_`t';
       *Value at 1.01*base wage;
   	   replace wage_policy=1.01*(1+`expreturn')^(`t'-1);
   	   replace valfn_`next'=highval_`next';
       sub_valfn, crra(`crra') etanext(`eta') next(`next') basehazard(`baseh') cnext(`c')
                  maxwage(`maxwage') discount(`discount') crra_type("`crra_type'");
       rename valfn_`t' highval_`t';
       *Value at fraction of base wage;
       forvalues s=1/`t' {;
         replace wage_policy=`firemult_`s''*(1+`expreturn')^(`t'-1);
         local mw_`s'=`firemult_`s''*`maxwage';
   	     replace valfn_`next'=lowval_`s'_`next';
   	     local lowc=lowval_`s'_`next';
         sub_valfn, crra(`crra') etanext(`eta') next(`next') basehazard(`baseh') cnext(`lowc')
                    maxwage(`mw_`s'') discount(`discount') crra_type("`crra_type'");
         rename valfn_`t' lowval_`s'_`t';
       };
       gen fireval_`t'=lowval_`t'_`t';
       *Elasticity calculation;       
       gen elast_`t'=((highval_`t'-baseval_`t')/baseval_`t')/0.01;
       gen eta_`t'=(`elast_exit')/elast_`t';
     };
     drop valfn_* wage_policy exper lowval_*;
    gen i=1;
    reshape long baseval_ fireval_ highval_ elast_ eta_ basehaz, i(i) j(t);
    rename baseval_ valfn;
    rename highval_ highvalfn;
    rename fireval_ valfn_fired;
    rename elast_ elast_valwage;
    rename eta_ eta;
    rename basehaz hazard;
    drop i;
    sort t;
    gen exper=_n-1;
    gen surv=1-hazard;
    gen lnsurv=ln(surv);
    gen lnSurv=sum(lnsurv); 
    gen Surv=exp(lnSurv[_n-1]);
    replace Surv=1 in 1;
    keep t exper hazard Surv valfn elast_valwage eta valfn_fired;
    gen c=valfn if exper>0;
    sort t;
    label var exper "Experience on entering period";
    label var c "Parameter for outside offer distn before period";
    label var valfn "Value function at beginning of period";
    label var valfn_fired "Continuation value for someone fired last period";
    *keep exper hazard Surv c valfn basewage eta;
  tempname eta_exit cmat firedmat;
  mkmat exper eta c, matrix(`eta_exit');
  mkmat exper valfn valfn_fired, matrix(`firedmat');
  local initialvalue=valfn[1];
  *Compute number of teachers as multiple of number hired each year, 
  *plus average outcomes and average wages.;
    su Surv, meanonly;
    local nteach_base=r(sum);
    gen basewage=(1+`expreturn')^(t-1);
    su basewage [aw=Surv], meanonly;
    local meanwage_base=r(mean);
    gen avgeffect=0 + `expeffect';
    su avgeffect [aw=Surv];
    local avgeffect_base=r(mean);
    local vareffect_base=r(Var) + (`sigma_mu'^2);
    local sdeffect_base=sqrt(`vareffect_base');
  *Need to figure out average exit elasticity;
       gen elast=`elast_exit';
       su elast, meanonly;
       local avgelast=r(mean);

  *We arent going to work out the elasticity of entry here, just the elasticity of the value with respect to the wage.;
  *We will do the rest later;
   local elast_valwage=elast_valwage[1];

  foreach item in sdeffect_base vareffect_base avgeffect_base meanwage_base nteach_base initialvalue elast_valwage avgelast {;
  	return scalar `item'=``item'';
  };
  return matrix eta_exit=`eta_exit';
  return matrix val_fired=`firedmat';
*  return matrix eta_entry=`eta_entry';
end;
