*sub_makesamp.do
*Prepares a sample from the joint distribution of mu-VA-observed performance, given parameters;

#delimit;

capture program drop sub_makesamp;
program define sub_makesamp, rclass;
  syntax, simulobs(real) basesamp(string) gridpts(real)
          [h(real 0.25) maxt(real 30)
           corrtruth(real 1) rsignal(real 0.4) sigma_mu(real 0.15)
           expeffect(string)
           *];
  if `"`expeffect'"'==`""' local expeffect="-0.07*(exper==0)-0.04*(exper==1)-0.02*(exper==2)";
           
  use id z_* if id<=`simulobs' using `basesamp';

  *Some calculations;
    local var_mu=`sigma_mu'^2;
    local var_e=`var_mu'*(1-`rsignal')/`rsignal';
    local sigma_e=sqrt(`var_e');
    local var_sig=`var_mu'+`var_e';
    local sigma_sig=sqrt(`var_sig');
    local priorvar0=`var_mu'*(1-`h');
    local var_prior0=`var_mu'*`h';
  	local priorsd0=sqrt(`priorvar0');
  **Work out the variance of the prior at each year -- will use this to make grid points;
     *Entering period t, have t-1 signals, on top of initial prior tau with mu|tau ~ N(tau, (1-h)s2_mu);
     *So prior variance is [((1-h)s2_mu)^-1 + (s2_e/(t-1))^-1]^-1;
    local priorvar_1=(1-`h')*`var_mu';
    forvalues t=2/`maxt' {;
    	 local s=`t'-1;
    	 local priorvar_`t'=1/( (1/`priorvar_`s'') + (1/`var_e'));
    };
    forvalues t=1/`maxt' {;
      local varprior_`t'=`var_mu'-`priorvar_`t'';
    	 local priorsd_`t'=sqrt(`priorvar_`t'');
    	 local sdprior_`t'=sqrt(`varprior_`t'');
      *di "t=`t', sdprior=`sdprior_`t'', priorsd=`priorsd_`t''";
    };


  gen pvtinfo=z_pvtinfo*sqrt(`var_prior0');
 *Want mu, muB to be correlated `corrtruth', E[mu|pvtinfo]=E[muB|pvtinfo]=pvtinfo;
  gen nu=z_nu*`priorsd0';
  local corrv=(`var_mu'*`corrtruth' - `var_prior0')/(`priorsd0'^2);
  gen nuB=`corrv'*nu + z_nuB*sqrt(1-`corrv'^2)*`priorsd0';
  gen mu=pvtinfo+nu;
  gen muB=pvtinfo+nuB;
  forvalues t=1/`maxt' {;
  	gen e`t'=z_e`t'*sqrt(`var_e');
  };
  keep id pvtinfo mu muB e1-e`maxt';
  
 *Assign gridpoints of private information, average signal to date, etc.;
  gen g_pvtinfo=round((`gridpts'+1)*normal(pvtinfo/sqrt(`var_prior0')));
  replace g_pvtinfo=1 if g_pvtinfo==0;
  replace g_pvtinfo=`gridpts' if g_pvtinfo==`gridpts'+1;
  gen avgva0=0;
  gen g_avgsig0=round((`gridpts'+1)*0.5);
  gen g_sig0=round((`gridpts'+1)*0.5);
  gen exper=0;
  forvalues t=1/`maxt' {;
  	local s=`t'-1;
  	replace exper=`s';
  	gen va`t'=mu+e`t';
  	gen vaunadj`t'=va`t'+`expeffect';
  	gen avgva`t'=(avgva`s'*`s' + va`t')/`t';
 	  gen g_avgsig`t'=round((`gridpts'+1)*normal((avgva`t'-pvtinfo)/sqrt(`priorvar0' + (`var_e'/`t'))));
    replace g_avgsig`t'=1 if g_avgsig`t'==0;
    replace g_avgsig`t'=`gridpts' if g_avgsig`t'==`gridpts'+1;
    *gen g_e`t'=round((`gridpts'+1)*normal(e`t'/sqrt(`var_e')))/(`gridpts'+1);
    *replace g_e`t'=1/(`gridpts'+1) if g_e`t'<1/(`gridpts'+1);
    *replace g_e`t'=`gridpts'/(`gridpts'+1) if g_e`t'>`gridpts'/(`gridpts'+1);

    *Prior on entering period `t';
    if `t'==1 gen prior`t'=pvtinfo;
    else gen prior`t'=((pvtinfo*`var_e'/`s') + (1-`h')*`var_mu'*avgva`s')/((`var_e'/`s') + (1-`h')*`var_mu');
    gen g_prior`t'=round((`gridpts'+1)*normal(prior`t'/`sdprior_`t''));
    replace g_prior`t'=1 if g_prior`t'==0;
    replace g_prior`t'=`gridpts' if g_prior`t'==`gridpts'+1;
    *Period `t' signal;
     gen sig`t'=va`t' - prior`t';
     gen g_sig`t'=round((`gridpts'+1)*normal(sig`t'/sqrt(`priorvar_`t'' + `var_e')));
     replace g_sig`t'=1 if g_sig`t'==0;
     replace g_sig`t'=`gridpts' if g_sig`t'==`gridpts'+1;
     
  };
  *drop va* ;
  drop exper;
  
  compress;

   di "***Calculated parameters***";
    foreach v in var_mu var_e sigma_e var_sig sigma_sig priorvar0 var_prior0 priorsd0 {;
    	di "`v' = ``v''";
    	return scalar `v'=``v'';
    	local baseparms `"`baseparms' `v'(``v'')"';
    };
    return local parms `"`baseparms'"';
end;
