#delimit;
cap program drop sub_summarize;
program define sub_summarize, rclass;
    args filename;

     sort exper;
     
   *Compute output;
     *Number of teachers under base policy;
       su Surv, meanonly;
       return scalar nteach_base=r(sum);
     *Number of teachers under alternative policy;
       su weight_policy, meanonly;
       return scalar nteach_policy=r(sum); 
     *Effectiveness - mean and SD - under base policy;
       su muB [aw=Surv];
       return scalar mu_mean_base=r(mean);
       return scalar mu_sd_base=r(sd);
       tempvar effect;
       gen `effect'=muB+expeffect;
       su `effect' [aw=Surv];
       return scalar impact_mean_base=r(mean);
       return scalar impact_sd_base=r(sd);
     *Effectiveness - mean and SD - under new policy;
       su muB [aw=weight_policy];
       return scalar mu_mean_policy=r(mean);
       return scalar mu_sd_policy=r(sd);
       su `effect' [aw=weight_policy];
       return scalar impact_mean_policy=r(mean);
       return scalar impact_sd_policy=r(sd);
     *Wage bill;
       su basewage [aw=Surv], meanonly;
       return scalar wage_base=r(mean);
       return scalar totwage_base=r(sum);
       su wage_policy [aw=weight_policy], meanonly;
       return scalar wage_policy=r(mean);
       return scalar totwage_policy=r(sum);
     *Experience;
       su exper [aw=Surv], meanonly;
       return scalar avgexper_base=r(mean);
       su exper [aw=weight_policy], meanonly;
       return scalar avgexper_policy=r(mean);
       gen byte exper1=(exper==1);
       gen byte experlt3=(exper<=3);
       su exper1 [aw=Surv], meanonly;
       return scalar frexper1_base=r(mean);
       su experlt3 [aw=Surv], meanonly;
       return scalar frexperlt3_base=r(mean);
       su exper1 [aw=weight_policy], meanonly;
       return scalar frexper1_policy=r(mean);
       su experlt3 [aw=weight_policy], meanonly;
       return scalar frexperlt3_policy=r(mean);
     *Attrition/retention;
      preserve;
      sort id year;
      by id: gen exit=(Surv_policy-Surv_policy[_n+1])/Surv_policy;
      collapse (mean) exit fired_ [aw=Surv_policy], by(exper);
      gen attrit=exit-fired_;
      rename fired_ fired;
      drop if exit==.;
      tempname hazardmat;
      mkmat exper exit fired attrit, matrix(`hazardmat');
      return matrix hazards=`hazardmat';
      restore, preserve;
      sort id year;
      by id: gen exit=(Surv_policy-Surv_policy[_n+1])/Surv_policy;
      gen attrit=exit-fired_;
      su fired_ [aw=Surv_policy], meanonly;
      return scalar hazard_fired=r(mean);
      su attrit [aw=Surv_policy], meanonly;
      return scalar hazard_attrit=r(mean);
      su exit [aw=Surv_policy], meanonly;
      return scalar hazard_exit=r(mean);
      restore;
     *Hiring;
      su entryweight if exper==0, meanonly;
      return scalar numhired=r(mean);
  sub_summarize_manip;
  return add;
end;       

capture program drop sub_summarize_manip;
program define sub_summarize_manip, rclass;
  args filename;
  if `"`filename'"'~="" use `"`filename'"', clear;
  cap gen Estar_=0;
  gen effectA_manip=mu+expeffect+Estar_;
  gen effectA=mu+expeffect;
  gen effectB=muB+expeffect;
  gen effectB_manip=effectB-Estar_;

  *Compute average outcomes in baseline;
   foreach t in A A_manip B B_manip {;
   	 su effect`t' [aw=Surv], meanonly;
   	 return scalar va`t'_base=r(mean);
   	 su effect`t' [aw=weight_policy], meanonly;
   	 return scalar va`t'_policy=r(mean);
   };
end;

