version 12.1
matrix drop _all
estimates clear

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

}
else {
	local pdir "~/projects/performancepay/project"
  local dofile "optimalfirethresholds"
	local sig "Not run as part of project!"
	set more off
}
local thisdir "`pdir'/varycontracts"

#delimit;

*Set parameters that will be used for all calls by this program;
 local simulparms `"npoints(149) simulobs(200000)"';

cap program drop makebase;
program define makebase;
  syntax, npoints(real) simulobs(real) outgrid(string) outsamp(string) 
          [sigma_mu(real 0.15) rsignal(real 0.4) expeffect(string) maxt(real 30)
           discount(real 0.97) basehazard(real 0.08) *];
  if `"`expeffect'"'==`""' local expeffect="-0.07*(exper==0)-0.04*(exper==1)-0.02*(exper==2)";
  local var_mu=`sigma_mu'^2;
  local var_e=`var_mu'*(1-`rsignal')/`rsignal';
  local sigma_e=sqrt(`var_e');

  drop _all;
  qui set obs `npoints';
  gen ptile=_n/(_N+1);
  gen gridpt=_n;
  gen z=invnormal(ptile);
  save `outgrid';
  
  drop _all;
  qui set obs `simulobs';
  gen id=_n;
  gen mu=`sigma_mu'*rnormal();
  expand `maxt';
  sort id;
  by id: gen t=_n;
  sort id t;
  gen e=`sigma_e'*rnormal();
  gen y=mu+e;
  by id: gen toty=sum(y);
  gen ybar=toty/t;
  keep id t mu y ybar ;
  gen lnsurv=ln(1-`basehazard')*(t>1);
  by id: gen totlnsurv=sum(lnsurv);
  gen Surv=exp(totlnsurv);
  drop lnsurv totlnsurv;
  gen h=`var_mu'/(`var_mu' + (`var_e'/t));
  gen posterior=h*ybar;
  
  save `outsamp';
  
end;

  
cap program drop computeV;
program define computeV, rclass;
  syntax, v0(real) firecost(string) basefile(string)
          [sigma_mu(real 0.15) rsignal(real 0.4) expeffect(string) maxt(real 30)
           discount(real 0.97) basehazard(real 0.08) quietly *];
  if `"`firecost'"'==`""' local firecost 0;
  if `"`expeffect'"'==`""' local expeffect="-0.07*(exper==0)-0.04*(exper==1)-0.02*(exper==2)";
  local var_mu=`sigma_mu'^2;
  local var_e=`var_mu'*(1-`rsignal')/`rsignal';
  local sigma_e=sqrt(`var_e');
  tempname c;
  matrix `c' = J(`maxt', 1, -99);
  
  *Start with people entering last period;
   local t=`maxt'-1;
   local next=`t'+1;
   local h_`t'=`var_mu'/(`var_mu' + (`var_e'/`t'));
     local sigma_`t'=1/((`t'/`var_e') + (1/`var_mu'));

   use `basefile', clear;
   su gridpt, meanonly;
   local npoints=r(N);
   
   if `t'>0 gen ybar_`t'=sqrt(`var_mu' + (`var_e'/`t'))*z;
   else gen ybar_`t'=0;
   gen exper=`t';
   gen avgyearsleft=(1-`basehazard');
   gen prior_`t'=`h_`t''*ybar_`t';
   gen theta_`t'=((`t'+`h_`t'')/(`t'+1))*ybar_`t';
   gen valifkeep_`next'=(1-`basehazard')*(prior_`t' + `discount' * `v0') + `basehazard'*`v0';
   gen valiffire_`next'=`v0' - (`firecost');
   gen fireafter`t'=(valifkeep_`next'<valiffire_`next');
   gen contval_`next'=(1-fireafter`t')*valifkeep_`next' + fireafter`t'*valiffire_`next';
   su ybar_`t' if fireafter`t'==1, meanonly;
   local c`t'=r(max);
   *su valifkeep_`next' if fireafter`t'==1, meanonly;
   *local valatc_`t'=r(max);
   if r(N)==0 {;
     su ybar_`t', meanonly;
     local c`t'=r(min);
     *su valifkeep_`next', meanonly;
     *local valatc_`t'=r(min);
   };
   matrix `c'[`t',1]=`c`t'';
   *local valatc `valatc_`t'';
   `quietly' di "Ybar threshold for firing after `t' is `c`t''.";
   *`quietly' di "Ybar threshold for firing after `t' is `c`t''. Value at threshold is `valatc_`t''.";
   keep gridpt fireafter`t' contval_`next'; 
   *This is whether fired before last period, and value of finishing next-to-last
   *period at this point;
   rename gridpt gridpt`t';
   tempfile contval`t';
   qui save `contval`t'';
   
  *Now earlier periods;
  local start=`maxt'-2;
  forvalues t=`start'(-1)1 {;
   local next=`t'+1;
   local nextnext=`next'+1;
   local h_`t'=`var_mu'/(`var_mu' + (`var_e'/`t'));
     local sigma_`t'=1/((`t'/`var_e') + (1/`var_mu'));
   use `basefile';
   if `t'>0 gen ybar_`t'=sqrt(`var_mu' + (`var_e'/`t'))*z;
   else gen ybar_`t'=0;
   gen exper=`t';
   gen prior_`t'=`h_`t''*ybar_`t';
   gen theta_`t'=((`t'+`h_`t'')/(`t'+1))*ybar_`t';
   qui expand `npoints';
   sort gridpt;
   by gridpt: gen newsigpt=_n;
   gen y_`next'=prior_`t' + invnormal(newsigpt/(`npoints'+1))*sqrt(`sigma_`t'' + `var_e');
   gen ybar_`next'=(`t'*ybar_`t' + y_`next')/`next';
   gen ptile_`next'=normal(ybar_`next'/sqrt(`var_mu' + (`var_e'/`next')));
   gen gridpt`next'=round(ptile_`next'*(`npoints'+1));
   qui replace gridpt`next'=1 if gridpt`next'==0;
   qui replace gridpt`next'=`npoints' if gridpt`next'==`npoints'+1;
   qui merge m:1 gridpt`next' using `contval`next'', assert(2 3) keep(3);
   collapse (mean) contval_`nextnext' ybar_`t' prior_`t', by(gridpt);
   gen exper=`t'-1;
   if `basehazard'>0 gen avgyearsleft=(-1*(1-`basehazard')/`basehazard')*(((1-`basehazard')^(`maxt'-`t')) - 1);
   gen valifkeep_`next'=(1-`basehazard')*(prior_`t' + (`expeffect') + `discount' * contval_`nextnext') + `basehazard'*`v0';
   gen valiffire_`next'=`v0' - (`firecost');
   gen fireafter`t'=(valifkeep_`next'<valiffire_`next');
   gen contval_`next'=(1-fireafter`t')*valifkeep_`next' + fireafter`t'*valiffire_`next';
   su ybar_`t' if fireafter`t'==1, meanonly;
   local c`t'=r(max);
   *su valifkeep_`next' if fireafter`t'==1, meanonly;
   *local valatc_`t'=r(max); 
   if r(N)==0 {;
     su ybar_`t', meanonly;
     local c`t'=r(min);
     *su valifkeep_`next', meanonly;
     *local valatc_`t'=r(min);
   };
   matrix `c'[`t',1]=`c`t'';
   `quietly' di "Ybar threshold for firing after `t' is `c`t''. ";
   *`quietly' di "Ybar threshold for firing after `t' is `c`t''. Value at threshold is `valatc_`t''.";
   keep gridpt fireafter`t' contval_`next';
   rename gridpt gridpt`t';
   tempfile contval`t';
   qui save `contval`t'';
  };   

   gen exper=0;
   gen val = `expeffect' + `discount'*contval_2;
   su val, meanonly;
   local startval=r(mean);
   di "Guessed starting value " `v0' ".  Found " `startval';
   return scalar v0=`startval';

  return matrix c=`c';
end;

cap program drop searchv0;
program define searchv0, rclass;
  syntax, v0(real) samp(string) [maxiters(real 50) toly0(real 0.001) tolc(real 0.0001) *];
  tempname lastc c;
  local y0=`v0';
  forvalues t=1/`maxiters' {;
  	qui computeV, v0(`y0') `options';
  	local y1=r(v0);
  	matrix `c'=r(c);
  	if `t'>1 {;
  		local diff=0;
  		local j=rowsof(`c');
  		forvalues r=1/`j' {;
  		  local d=el(`c', `r', 1)-el(`lastc', `r', 1);
  		  if abs(`d')>`diff' local diff=abs(`d');
  		};
  	};
    local dy=abs(`y1'-`y0');
    if `t'==1 di "Search V0: On iteration 1, y=`y1', dy=`dy'";
    else {;
    	di "Search V0: On iteration `t', y=`y1', dy=`dy', max(dc)=`diff'";
    	if `dy'<`toly0' & `diff'<`tolc' {;
    	  di "Converged!";
    	  continue, break;
    	};
    };
  	*if `t'==1 matrix allc=`c';
  	*else matrix allc=allc, `c';
  	*di "SearchV0: On iteration `t', started with `y0' and finished with `y1'";
  	local y0 `y1';
  	matrix `lastc'=`c';
  };
  *Now figure out how many teachers are fired;
   use `samp', clear;
   su t, meanonly;
   local nperiods=r(max);
   qui gen fired=.;
   forvalues t=1/`nperiods' {;
   	 local c`t'=el(`c', `t', 1);
   	 qui replace fired=(ybar<`c`t'') if t==`t';
   };
   su fired [aw=Surv], meanonly;
   local frfired=r(mean);
   
  return scalar v0=`y0';
  return matrix c=`c';
  return scalar frfired=`frfired';
end;

capture program drop loop;
program define loop;
  syntax, at(numlist sort) [startval(real 0) save *];
  local n=1;
  local initv0=`startval';
  tempfile results;
  tempname oneresult;
  foreach cost of local at {;
  	di "Starting search for firecost=`cost', with v0=`initv0'";
  	searchv0, firecost("(`cost'*avgyearsleft)") v0(`initv0') `options';
  	matrix `oneresult'=r(c)', `n', `cost', r(v0), r(frfired);
  	local initv0=r(v0);
  	local nperiod=colsof(`oneresult')-4;
  	local ncol=colsof(`oneresult')-3;
  	local costcol=colsof(`oneresult')-2;
  	local v0col=colsof(`oneresult')-1;
  	local firedcol=colsof(`oneresult');
  	drop _all;
  	set obs 1;
  	svmat `oneresult';
  	forvalues col=1/`nperiod' {;
  		rename `oneresult'`col' c`col';
  	};
  	rename `oneresult'`ncol' n;
  	rename `oneresult'`costcol' firecost;
 	  rename `oneresult'`v0col' v0;
 	  rename `oneresult'`firedcol' frfired;
  	if `n'==1 save `results';
  	else {;
  		append using `results';
  		save `results', replace;
    };
    local n=`n'+1;
  };
  sort n;
  drop n;
end;
  		
  	
  	
tempfile grid samp values;

makebase, `simulparms' outgrid(`grid') outsamp(`samp');

loop, at(0.01(0.005)0.15 0.16(0.01)0.25 ) startval(1.29) samp(`samp') basefile(`grid');
gen parmset=-1;
sort firecost;
tempfile base p0 p1 p2 p3 p4;
save `base';

loop, at(0.025 (0.00125) 0.045)) startval(1.29) samp(`samp') basefile(`grid'); 
gen parmset=0;
sort firecost;
save `p0';

loop, at(0.1025 0.1075) startval(1.29) samp(`samp') basefile(`grid'); 
gen parmset=1;
sort firecost;
save `p1';

loop, at(0.011 (0.001) 0.019)  startval(1.29) samp(`samp') basefile(`grid'); 
gen parmset=2;
sort firecost;
save `p2';

loop, at(0.001 (0.001) 0.009)  startval(1.29) samp(`samp') basefile(`grid'); 
gen parmset=3;
sort firecost;
save `p3';



/* Preliminary runs
at       v0     fr fired
-0.001 / 2.06 / 61%
-0.002 / 2.13 / 62%
-0.003 / 2.22 / 63%
-0.004 / 2.32 / 64%
-0.005 / 2.42 / 65%
-0.006 / 2.52 / 67%
-0.007 / 2.63 / 68%
-0.008 / 2.74 / 69%
-0.0085/ 2.81 / 70%
-0.009 / 2.88 / 71%
-0.01  / 3.02 / 72%
-0.011 / 3.13 / 73%
-0.012 / 3.28 / 74%
-0.0125/      / 75%
-0.013 / 3.43 / 76%
-0.014 / 3.60 / 77%
-0.0145/      / 78%
-0.015 / 3.82 / 79%
-0.0155/      / 79%
-0.016 /      / 80%
-0.02  / 4.7  / 85%
*/
loop, at(-0.016(0.001)-0.001 -0.0085 -0.0125 -0.0145 -0.02 0 0.0225) startval(3.85) samp(`samp') basefile(`grid');
gen parmset=4;
sort firecost;
save `p4';

use `base';
append using `p0';
append using `p1';
append using `p2';
append using `p3';
append using `p4';

sort firecost parmset;
by firecost: drop if parmset[1]==-1 & _n>1;
by firecost: assert _n==1;
sort parmset firecost;
gen num=_n;

reshape long c, i(num) j(t);
sort num t;

list num parmset firecost v0 frfired if t==1, clean;

 save `thisdir'/`dofile'.dta, replace;
if `doasproject'==1 {;
	project, creates(`thisdir'/`dofile'.dta);
};
*drop _all;
*svmat c;
