version 12.1
matrix drop _all
estimates clear
set more off

cap project, doinfo
if _rc==0 {
	local doasproject=1
	local pdir "`r(pdir)'"						  	    // the project's main dir.
	local dofile "`r(dofile)'"						    // do-file's stub name
  local sig {bind:{hi:[RP : `dofile'.do]}}	// a signature in notes

  project, uses(vary_frfired.dta)
  project, uses(vary_frfiredavgva.dta)
  project, uses(vary_frfiredoptimal.dta)
  project, uses(optimalfirethresholds.dta)
  project, uses("`pdir'/scratch/drawsamp.dta")
  project, original("`pdir'/subroutines/sub_findthresholds.do")
}
else {
	local doasproject=0
	local pdir "~/projects/performancepay/project"
  local dofile "vary_rescale"
	local sig "Not run as part of project!"
}
local thisdir "`pdir'/varycontracts"
local scratch "`pdir'/scratch"
qui do `pdir'/subroutines/sub_findthresholds.do;

#delimit;

local gridpts=149;
local maxt=30;
local expadjust=1;
local basehazard="0.08";
local expeffect="-0.07*(exper==0)-0.04*(exper==1)-0.02*(exper==2)";

local sigma_mu=0.15;
local sigma_e=sqrt(1.5)*`sigma_mu';
local var_e=`sigma_e'^2;
local var_mu=`sigma_mu'^2;

*Make basic simulation sample;
  use `scratch'/drawsamp, clear;
  gen mu=`sigma_mu'*z_nu;
  gen totva=0;
  forvalues t=1/30 {;
    gen e`t'=`sigma_e'*z_e`t';
    gen va`t'=mu+e`t';
    replace totva=totva+va`t';
    gen avgva`t'=totva/`t';
    gen postmean`t'=(`var_mu'/(`var_mu'+(`var_e'/`t')))*avgva`t';
  };
  keep id mu avgva* postmean*;
  drop avgva30 postmean30;
  egen lowestva=rmin(avgva*);
  egen lowestposterior=rmin(postmean*);
  tempfile simsamp;
  save `simsamp';

*Figure out which contracts to run;
 use `thisdir'/vary_frfired;
 sort _frfired;
 by _frfired: keep if _n==1;
 mkmat _frfired, matrix(frac_posterior);
 su _frfired, meanonly;
 local nruns_posterior=r(N);
 matrix frac_posterior=frac_posterior, J(`nruns_posterior', 2, 0);
 matrix colnames frac_posterior = frfired threshold frfired_cumul;

 use `thisdir'/vary_frfiredavgva, clear;
 sort _frfired;
 by _frfired: keep if _n==1;
 mkmat _frfired, matrix(frac_avgva);
 su _frfired, meanonly;
 local nruns_avgva=r(N);
 matrix frac_avgva=frac_avgva, J(`nruns_avgva', 2, 0);
 matrix colnames frac_avgva = frfired threshold frfired_cumul;

 use `thisdir'/vary_frfiredoptimal, clear;
 sort _num;
 by _num: keep if _n==1;
 mkmat _num _frfired, matrix(frac_optimal);
 su _num, meanonly;
 local nruns_optimal=r(N);
 matrix frac_optimal=frac_optimal, J(`nruns_optimal', 1, 0);
 matrix colnames frac_optimal = num frfired frfired_cumul;
 matrix thresholds_optimal=J(`nruns_optimal', 29, -100);
 
*Find thresholds for each contract; 
 di "Starting computation of thresholds for posterior mean contract";
 forvalues r=1/`nruns_posterior' {;
 	 local f=el(frac_posterior, `r', 1);
   di "Starting run `r'/`nruns_posterior' with f=`f'";
   sub_findthresholds, ctype("fire") gridpts(`gridpts') sigma_mu(`sigma_mu') sigma_e(`sigma_e') maxt(`maxt')
                       expadjust(`expadjust') basehazard(`"`basehazard'"') var_e(`var_e') var_mu(`var_mu')
                       frfired(`f') firerule("posterior");
   matrix frac_posterior[`r', 2]=r(firethreshold);
 };
 di "Starting computation of thresholds for avg VA contract";
 forvalues r=1/`nruns_avgva' {;
 	 local f=el(frac_avgva, `r', 1);
   di "Starting run `r'/`nruns_avgva' with f=`f'";
   sub_findthresholds, ctype("fire") gridpts(`gridpts') sigma_mu(`sigma_mu') sigma_e(`sigma_e') maxt(`maxt')
                       expadjust(`expadjust') basehazard(`"`basehazard'"') var_e(`var_e') var_mu(`var_mu')
                       frfired(`f') firerule("avgva");
   matrix frac_avgva[`r', 2]=r(firethreshold);
 };

 forvalues r=1/`nruns_optimal' {;
 	 local run=el(frac_optimal, `r', 1);
 	 use t c num if num==`run' using optimalfirethresholds, clear;
 	 sort t;
 	 keep if t<30;
 	 mkmat c, matrix(optthresh);
 	 matrix thresholds_optimal[`r', 1]=optthresh';
 };

*Compute cumulative firing rates for each contract;
 use lowestva lowestposterior using `simsamp', clear;
 gen byte everfired=.;
 forvalues r=1/`nruns_posterior' {; 
 	 replace everfired=(lowestposterior<el(frac_posterior, `r', 2));
 	 su everfired, meanonly;
	 matrix frac_posterior[`r', 3]=r(mean);
 };
 forvalues r=1/`nruns_avgva' {; 
 	 replace everfired=(lowestva<el(frac_avgva, `r', 2));
 	 su everfired, meanonly;
	 matrix frac_avgva[`r', 3]=r(mean);
 };
 use `simsamp', clear;
 gen byte everfired=.;
 forvalues r=1/`nruns_optimal' {;
 	 replace everfired=0;
 	 forvalues t=1/29 {;
 	 	 qui replace everfired=1 if avgva`t'<el(thresholds_optimal, `r', `t');
 	 };
 	 su everfired, meanonly;
 	 matrix frac_optimal[`r', 3]=r(mean);
 };

*And compile and save results;
  tempfile posterior avgva optimal;
  drop _all;
  set obs `nruns_posterior';
  svmat frac_posterior, names(col);
  gen policytype="frfired";
  rename frfired policy;
  save `posterior';
  drop _all;
  set obs `nruns_avgva';
  svmat frac_avgva, names(col);  
  gen policytype="frfiredavgva";
  rename frfired policy;
  save `avgva';
  drop _all;
  set obs `nruns_optimal';
  svmat frac_optimal, names(col);
  rename num _num;
  rename frfired policy;
  gen policytype="frfiredoptimal";
  save `optimal';
  use `posterior';
  append using `avgva';
  append using `optimal';
  
  save `thisdir'/`dofile', replace;
  
if `doasproject'==1 project, creates(`thisdir'/`dofile'.dta);  
